<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('delivery');

// 记录访问日志
record_log('访问配送员管理页面');

// 初始化变量
$action = isset($_GET['action']) ? $_GET['action'] : 'list';
$id = isset($_GET['id']) ? intval($_GET['id']) : 0;
$searchName = isset($_GET['searchName']) ? trim($_GET['searchName']) : '';
$searchPhone = isset($_GET['searchPhone']) ? trim($_GET['searchPhone']) : '';
$searchStatus = isset($_GET['searchStatus']) ? $_GET['searchStatus'] : '';
$error = '';
$success = '';

// 获取配送员状态文本
function getStatusText($status)
{
    switch ($status) {
        case 0:
            return '离职';
        case 1:
            return '在职';
        case 2:
            return '休假';
        default:
            return '未知';
    }
}

// 获取状态CSS类
function getStatusClass($status)
{
    switch ($status) {
        case 0:
            return 'text-danger';
        case 1:
            return 'text-success';
        case 2:
            return 'text-warning';
        default:
            return '';
    }
}

// 处理添加配送员
if ($action == 'add' && $_SERVER['REQUEST_METHOD'] == 'POST') {
    try {
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $phone = isset($_POST['phone']) ? trim($_POST['phone']) : '';
        $area = isset($_POST['area']) ? trim($_POST['area']) : '';
        $vehicle_type = isset($_POST['vehicle_type']) ? trim($_POST['vehicle_type']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        // 验证数据
        if (empty($name) || empty($phone) || empty($area) || empty($vehicle_type)) {
            throw new Exception('请填写完整信息');
        }

        // 检查手机号是否已存在
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM delivery_staff WHERE phone = ?");
        $stmt->execute([$phone]);
        if ($stmt->fetchColumn() > 0) {
            throw new Exception('该手机号已存在');
        }

        // 插入数据
        $stmt = $pdo->prepare("INSERT INTO delivery_staff (name, phone, area, vehicle_type, status) VALUES (?, ?, ?, ?, ?)");
        $stmt->execute([$name, $phone, $area, $vehicle_type, $status]);

        record_log("添加配送员: {$name}");
        $success = '添加配送员成功';
        $action = 'list'; // 重定向到列表页

    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}

// 处理更新配送员
if ($action == 'update' && $_SERVER['REQUEST_METHOD'] == 'POST') {
    try {
        $id = isset($_POST['id']) ? intval($_POST['id']) : 0;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $phone = isset($_POST['phone']) ? trim($_POST['phone']) : '';
        $area = isset($_POST['area']) ? trim($_POST['area']) : '';
        $vehicle_type = isset($_POST['vehicle_type']) ? trim($_POST['vehicle_type']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        // 验证数据
        if (empty($name) || empty($phone) || empty($area) || empty($vehicle_type) || $id <= 0) {
            throw new Exception('请填写完整信息');
        }

        // 检查手机号是否已存在（排除当前编辑的记录）
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM delivery_staff WHERE phone = ? AND id != ?");
        $stmt->execute([$phone, $id]);
        if ($stmt->fetchColumn() > 0) {
            throw new Exception('该手机号已被其他配送员使用');
        }

        // 更新数据
        $stmt = $pdo->prepare("UPDATE delivery_staff SET name = ?, phone = ?, area = ?, vehicle_type = ?, status = ? WHERE id = ?");
        $stmt->execute([$name, $phone, $area, $vehicle_type, $status, $id]);

        record_log("更新配送员信息: ID={$id}, {$name}");
        $success = '更新配送员信息成功';
        $action = 'list'; // 重定向到列表页

    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}

// 处理删除配送员
if ($action == 'delete' && $id > 0) {
    try {
        // 先检查该配送员是否有未完成的配送任务
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM delivery_tasks WHERE staff_id = ? AND status IN (1, 2)");
        $stmt->execute([$id]);
        if ($stmt->fetchColumn() > 0) {
            throw new Exception('该配送员有未完成的配送任务，无法删除');
        }

        // 获取配送员名称（用于日志记录）
        $stmt = $pdo->prepare("SELECT name FROM delivery_staff WHERE id = ?");
        $stmt->execute([$id]);
        $staffName = $stmt->fetchColumn();

        // 开始事务
        $pdo->beginTransaction();

        // 删除相关评价记录
        $stmt = $pdo->prepare("DELETE FROM delivery_ratings WHERE staff_id = ?");
        $stmt->execute([$id]);

        // 删除排班记录
        $stmt = $pdo->prepare("DELETE FROM delivery_schedules WHERE staff_id = ?");
        $stmt->execute([$id]);

        // 将相关配送任务的staff_id设为NULL
        $stmt = $pdo->prepare("UPDATE delivery_tasks SET staff_id = NULL WHERE staff_id = ?");
        $stmt->execute([$id]);

        // 删除配送员
        $stmt = $pdo->prepare("DELETE FROM delivery_staff WHERE id = ?");
        $stmt->execute([$id]);

        // 提交事务
        $pdo->commit();

        record_log("删除配送员: {$staffName} (ID: {$id})");
        $success = '删除配送员成功';
    } catch (Exception $e) {
        // 回滚事务
        if ($pdo->inTransaction()) {
            $pdo->rollBack();
        }
        $error = $e->getMessage();
    }

    $action = 'list'; // 重定向到列表页
}

// 构建搜索条件
$whereClause = "1=1";
$params = [];

if (!empty($searchName)) {
    $whereClause .= " AND name LIKE ?";
    $params[] = "%{$searchName}%";
}

if (!empty($searchPhone)) {
    $whereClause .= " AND phone LIKE ?";
    $params[] = "%{$searchPhone}%";
}

if ($searchStatus !== '') {
    $whereClause .= " AND status = ?";
    $params[] = $searchStatus;
}

// 分页参数
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$limit = 10;
$offset = ($page - 1) * $limit;

// 查询总记录数
$stmt = $pdo->prepare("SELECT COUNT(*) FROM delivery_staff WHERE {$whereClause}");
$stmt->execute($params);
$totalRecords = $stmt->fetchColumn();
$totalPages = ceil($totalRecords / $limit);

// 查询配送员列表
$stmt = $pdo->prepare("SELECT * FROM delivery_staff WHERE {$whereClause} ORDER BY id DESC LIMIT {$offset}, {$limit}");
$stmt->execute($params);
$staffList = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>配送员管理</h2>
        </div>

        <div class="content">
            <?php if (!empty($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (!empty($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <?php if ($action == 'list'): ?>
                <!-- 搜索表单 -->
                <div class="search-container">
                    <form action="staff.php" method="get" class="search-form">
                        <div class="form-group">
                            <input type="text" name="searchName" placeholder="配送员姓名" value="<?php echo htmlspecialchars($searchName); ?>">
                        </div>
                        <div class="form-group">
                            <input type="text" name="searchPhone" placeholder="手机号码" value="<?php echo htmlspecialchars($searchPhone); ?>">
                        </div>
                        <div class="form-group">
                            <select name="searchStatus">
                                <option value="">所有状态</option>
                                <option value="0" <?php echo $searchStatus === '0' ? 'selected' : ''; ?>>离职</option>
                                <option value="1" <?php echo $searchStatus === '1' ? 'selected' : ''; ?>>在职</option>
                                <option value="2" <?php echo $searchStatus === '2' ? 'selected' : ''; ?>>休假</option>
                            </select>
                        </div>
                        <button type="submit" class="btn btn-primary">搜索</button>
                        <a href="staff.php?action=add" class="btn btn-success">添加配送员</a>
                    </form>
                </div>

                <!-- 配送员列表 -->
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>姓名</th>
                                <th>联系电话</th>
                                <th>负责区域</th>
                                <th>交通工具</th>
                                <th>平均评分</th>
                                <th>状态</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($staffList)): ?>
                                <tr>
                                    <td colspan="9" class="text-center">暂无配送员数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($staffList as $staff): ?>
                                    <tr>
                                        <td><?php echo $staff['id']; ?></td>
                                        <td><?php echo htmlspecialchars($staff['name']); ?></td>
                                        <td><?php echo htmlspecialchars($staff['phone']); ?></td>
                                        <td><?php echo htmlspecialchars($staff['area']); ?></td>
                                        <td><?php echo htmlspecialchars($staff['vehicle_type']); ?></td>
                                        <td><?php echo number_format($staff['avg_rating'], 1); ?></td>
                                        <td class="<?php echo getStatusClass($staff['status']); ?>"><?php echo getStatusText($staff['status']); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($staff['create_time'])); ?></td>
                                        <td>
                                            <a href="staff.php?action=edit&id=<?php echo $staff['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                            <a href="javascript:void(0)" onclick="if(confirm('确定要删除该配送员吗？')) location.href='staff.php?action=delete&id=<?php echo $staff['id']; ?>'" class="btn btn-sm btn-danger">删除</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 分页 -->
                <?php if ($totalPages > 1): ?>
                    <div class="pagination">
                        <?php for ($i = 1; $i <= $totalPages; $i++): ?>
                            <a href="staff.php?page=<?php echo $i; ?>&searchName=<?php echo urlencode($searchName); ?>&searchPhone=<?php echo urlencode($searchPhone); ?>&searchStatus=<?php echo urlencode($searchStatus); ?>" class="<?php echo $i == $page ? 'active' : ''; ?>"><?php echo $i; ?></a>
                        <?php endfor; ?>
                    </div>
                <?php endif; ?>

            <?php elseif ($action == 'add'): ?>
                <!-- 添加配送员表单 -->
                <form action="staff.php?action=add" method="post" class="form">
                    <h3>添加配送员</h3>

                    <div class="form-group">
                        <label for="name">姓名：</label>
                        <input type="text" id="name" name="name" required>
                    </div>

                    <div class="form-group">
                        <label for="phone">联系电话：</label>
                        <input type="tel" id="phone" name="phone" required pattern="[0-9]{11}">
                    </div>

                    <div class="form-group">
                        <label for="area">负责区域：</label>
                        <input type="text" id="area" name="area" required>
                    </div>

                    <div class="form-group">
                        <label for="vehicle_type">交通工具：</label>
                        <select id="vehicle_type" name="vehicle_type" required>
                            <option value="">请选择</option>
                            <option value="电动车">电动车</option>
                            <option value="电动三轮">电动三轮</option>
                            <option value="摩托车">摩托车</option>
                            <option value="汽车">汽车</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="status">状态：</label>
                        <select id="status" name="status" required>
                            <option value="1" selected>在职</option>
                            <option value="2">休假</option>
                            <option value="0">离职</option>
                        </select>
                    </div>

                    <div class="form-buttons">
                        <button type="submit" class="btn btn-primary">保存</button>
                        <a href="staff.php" class="btn btn-secondary">返回</a>
                    </div>
                </form>

            <?php elseif ($action == 'edit' && $id > 0): ?>
                <?php
                // 获取配送员信息
                $stmt = $pdo->prepare("SELECT * FROM delivery_staff WHERE id = ?");
                $stmt->execute([$id]);
                $staff = $stmt->fetch();

                if (!$staff) {
                    echo '<div class="alert alert-danger">配送员不存在</div>';
                    echo '<p><a href="staff.php" class="btn btn-secondary">返回列表</a></p>';
                } else {
                ?>
                    <!-- 编辑配送员表单 -->
                    <form action="staff.php?action=update" method="post" class="form">
                        <h3>编辑配送员</h3>

                        <input type="hidden" name="id" value="<?php echo $staff['id']; ?>">

                        <div class="form-group">
                            <label for="name">姓名：</label>
                            <input type="text" id="name" name="name" value="<?php echo htmlspecialchars($staff['name']); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="phone">联系电话：</label>
                            <input type="tel" id="phone" name="phone" value="<?php echo htmlspecialchars($staff['phone']); ?>" required pattern="[0-9]{11}">
                        </div>

                        <div class="form-group">
                            <label for="area">负责区域：</label>
                            <input type="text" id="area" name="area" value="<?php echo htmlspecialchars($staff['area']); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="vehicle_type">交通工具：</label>
                            <select id="vehicle_type" name="vehicle_type" required>
                                <option value="">请选择</option>
                                <option value="电动车" <?php echo $staff['vehicle_type'] == '电动车' ? 'selected' : ''; ?>>电动车</option>
                                <option value="电动三轮" <?php echo $staff['vehicle_type'] == '电动三轮' ? 'selected' : ''; ?>>电动三轮</option>
                                <option value="摩托车" <?php echo $staff['vehicle_type'] == '摩托车' ? 'selected' : ''; ?>>摩托车</option>
                                <option value="汽车" <?php echo $staff['vehicle_type'] == '汽车' ? 'selected' : ''; ?>>汽车</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status" required>
                                <option value="1" <?php echo $staff['status'] == 1 ? 'selected' : ''; ?>>在职</option>
                                <option value="2" <?php echo $staff['status'] == 2 ? 'selected' : ''; ?>>休假</option>
                                <option value="0" <?php echo $staff['status'] == 0 ? 'selected' : ''; ?>>离职</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="staff.php" class="btn btn-secondary">返回</a>
                        </div>
                    </form>
                <?php } ?>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>