<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance');

// 记录访问日志
record_log('访问收入管理页面');

// 处理动作参数
$action = isset($_GET['action']) ? $_GET['action'] : 'list';
$success_message = '';
$error_message = '';

// 处理添加收入记录
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['add_income'])) {
    $category = isset($_POST['category']) ? $_POST['category'] : '';
    $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
    $record_date = isset($_POST['record_date']) ? $_POST['record_date'] : date('Y-m-d');
    $description = isset($_POST['description']) ? $_POST['description'] : '';
    $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 1; // 默认门店ID

    if (empty($category) || $amount <= 0) {
        $error_message = '请填写有效的收入类别和金额';
    } else {
        $stmt = $pdo->prepare("
            INSERT INTO finance_records (type, category, amount, store_id, description, record_date)
            VALUES (1, ?, ?, ?, ?, ?)
        ");
        $result = $stmt->execute([$category, $amount, $store_id, $description, $record_date]);

        if ($result) {
            record_log("添加收入记录: {$category}, 金额: {$amount}");
            $success_message = '收入记录添加成功';
            // 添加成功后返回列表页面
            $action = 'list';
        } else {
            $error_message = '收入记录添加失败，请重试';
        }
    }
}

// 筛选条件处理
$where_conditions = ["type = 1"]; // 只查询收入记录
$params = [];

// 获取门店列表
$stmt = $pdo->query("SELECT id, name FROM stores ORDER BY id");
$stores = $stmt->fetchAll(PDO::FETCH_ASSOC);

// 获取收入类别列表
$stmt = $pdo->query("
    SELECT DISTINCT category 
    FROM finance_records 
    WHERE type = 1 
    ORDER BY category
");
$categories = $stmt->fetchAll(PDO::FETCH_COLUMN);

// 筛选条件处理
if ($_SERVER['REQUEST_METHOD'] == 'GET' && isset($_GET['filter'])) {
    if (!empty($_GET['store_id']) && $_GET['store_id'] != 'all') {
        $where_conditions[] = "store_id = ?";
        $params[] = intval($_GET['store_id']);
    }

    if (!empty($_GET['category']) && $_GET['category'] != 'all') {
        $where_conditions[] = "category = ?";
        $params[] = $_GET['category'];
    }

    if (!empty($_GET['date_from'])) {
        $where_conditions[] = "record_date >= ?";
        $params[] = $_GET['date_from'];
    }

    if (!empty($_GET['date_to'])) {
        $where_conditions[] = "record_date <= ?";
        $params[] = $_GET['date_to'];
    }

    if (!empty($_GET['min_amount'])) {
        $where_conditions[] = "amount >= ?";
        $params[] = floatval($_GET['min_amount']);
    }

    if (!empty($_GET['max_amount'])) {
        $where_conditions[] = "amount <= ?";
        $params[] = floatval($_GET['max_amount']);
    }
}

// 构建SQL查询
$where_clause = !empty($where_conditions) ? ' WHERE ' . implode(' AND ', $where_conditions) : '';
$sql = "
    SELECT fr.*, s.name as store_name 
    FROM finance_records fr
    LEFT JOIN stores s ON fr.store_id = s.id
    {$where_clause}
    ORDER BY fr.record_date DESC, fr.id DESC
";

// 执行查询
$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$records = $stmt->fetchAll(PDO::FETCH_ASSOC);

// 计算总金额
$total_amount = 0;
foreach ($records as $record) {
    $total_amount += $record['amount'];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>收入管理</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt;
                <span>收入管理</span>
            </div>
        </div>

        <div class="content">
            <?php if (!empty($success_message)): ?>
                <div class="alert alert-success"><?php echo $success_message; ?></div>
            <?php endif; ?>

            <?php if (!empty($error_message)): ?>
                <div class="alert alert-danger"><?php echo $error_message; ?></div>
            <?php endif; ?>

            <?php if ($action === 'list'): ?>
                <!-- 操作栏 -->
                <div class="action-bar">
                    <a href="?action=add" class="btn btn-primary">添加收入</a>
                </div>

                <!-- 筛选表单 -->
                <div class="filter-form">
                    <h3>收入记录筛选</h3>
                    <form method="get" action="income.php">
                        <input type="hidden" name="filter" value="1">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="store_id">门店</label>
                                <select name="store_id" id="store_id">
                                    <option value="all">全部门店</option>
                                    <?php foreach ($stores as $store): ?>
                                        <option value="<?php echo $store['id']; ?>" <?php echo (isset($_GET['store_id']) && $_GET['store_id'] == $store['id']) ? 'selected' : ''; ?>>
                                            <?php echo $store['name']; ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="filter-item">
                                <label for="category">收入类别</label>
                                <select name="category" id="category">
                                    <option value="all">全部类别</option>
                                    <?php foreach ($categories as $category): ?>
                                        <option value="<?php echo $category; ?>" <?php echo (isset($_GET['category']) && $_GET['category'] == $category) ? 'selected' : ''; ?>>
                                            <?php echo $category; ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="date_from">开始日期</label>
                                <input type="date" name="date_from" id="date_from" value="<?php echo isset($_GET['date_from']) ? $_GET['date_from'] : ''; ?>">
                            </div>
                            <div class="filter-item">
                                <label for="date_to">结束日期</label>
                                <input type="date" name="date_to" id="date_to" value="<?php echo isset($_GET['date_to']) ? $_GET['date_to'] : ''; ?>">
                            </div>
                        </div>
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="min_amount">最小金额</label>
                                <input type="number" name="min_amount" id="min_amount" min="0" step="0.01" value="<?php echo isset($_GET['min_amount']) ? $_GET['min_amount'] : ''; ?>">
                            </div>
                            <div class="filter-item">
                                <label for="max_amount">最大金额</label>
                                <input type="number" name="max_amount" id="max_amount" min="0" step="0.01" value="<?php echo isset($_GET['max_amount']) ? $_GET['max_amount'] : ''; ?>">
                            </div>
                            <div class="filter-item" style="display: flex; align-items: flex-end;">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="income.php" class="btn btn-secondary" style="margin-left: 10px;">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- 收入记录列表 -->
                <h3>收入记录列表</h3>
                <div class="table-container">
                    <div style="text-align: right; margin-bottom: 10px;">
                        <strong>查询结果: <?php echo count($records); ?> 条记录，总金额: ￥<?php echo number_format($total_amount, 2); ?></strong>
                    </div>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>日期</th>
                                <th>类别</th>
                                <th>金额</th>
                                <th>门店</th>
                                <th>说明</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($records) > 0): ?>
                                <?php foreach ($records as $record): ?>
                                    <tr>
                                        <td><?php echo $record['id']; ?></td>
                                        <td><?php echo $record['record_date']; ?></td>
                                        <td><?php echo $record['category']; ?></td>
                                        <td>￥<?php echo number_format($record['amount'], 2); ?></td>
                                        <td><?php echo $record['store_name']; ?></td>
                                        <td><?php echo $record['description']; ?></td>
                                        <td>
                                            <a href="income_detail.php?id=<?php echo $record['id']; ?>" class="btn btn-sm btn-secondary">详情</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无收入记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php elseif ($action === 'add'): ?>
                <!-- 添加收入表单 -->
                <div class="form-container">
                    <h3>添加收入记录</h3>
                    <form method="post" action="income.php">
                        <div class="form-group">
                            <label for="category">收入类别 <span class="text-danger">*</span></label>
                            <select name="category" id="category" required>
                                <option value="">请选择类别</option>
                                <option value="订单收入">订单收入</option>
                                <option value="会员充值">会员充值</option>
                                <option value="门店销售">门店销售</option>
                                <option value="会员费">会员费</option>
                                <option value="其他收入">其他收入</option>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="amount">金额 <span class="text-danger">*</span></label>
                            <input type="number" name="amount" id="amount" min="0.01" step="0.01" required placeholder="请输入金额">
                        </div>
                        <div class="form-group">
                            <label for="store_id">所属门店</label>
                            <select name="store_id" id="store_id">
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>"><?php echo $store['name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="record_date">记录日期</label>
                            <input type="date" name="record_date" id="record_date" value="<?php echo date('Y-m-d'); ?>">
                        </div>
                        <div class="form-group">
                            <label for="description">说明</label>
                            <input type="text" name="description" id="description" placeholder="请输入收入说明">
                        </div>
                        <div class="form-actions">
                            <button type="submit" name="add_income" class="btn btn-primary">添加收入</button>
                            <a href="income.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>