<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('marketing');

// 记录访问日志
record_log('访问促销活动页面');

// 处理动作参数
$action = isset($_GET['action']) ? $_GET['action'] : 'list';
$success_message = '';
$error_message = '';

// 处理促销活动状态变更
if ($action === 'toggle_status' && isset($_GET['id'])) {
    $id = intval($_GET['id']);
    try {
        // 判断是否为优惠券模式
        $is_coupon_mode = isset($_GET['coupon_mode']) && $_GET['coupon_mode'] == 1;
        $type_condition = $is_coupon_mode ? "type IN (1, 2, 6)" : "1=1";

        // 获取当前状态
        $stmt = $pdo->prepare("SELECT status FROM marketing_campaigns WHERE id = ? AND $type_condition");
        $stmt->execute([$id]);
        $current = $stmt->fetch();

        if ($current) {
            $new_status = $current['status'] == 1 ? 0 : 1;
            $stmt = $pdo->prepare("UPDATE marketing_campaigns SET status = ? WHERE id = ?");
            $stmt->execute([$new_status, $id]);

            $status_text = $new_status == 1 ? '启用' : '禁用';
            $activity_type = $is_coupon_mode ? '优惠券活动' : '营销活动';
            record_log("${status_text}${activity_type}: ID $id");
            $success_message = "${activity_type}已${status_text}";
        } else {
            $error_message = $is_coupon_mode ? '优惠券活动不存在' : '营销活动不存在';
        }
    } catch (PDOException $e) {
        $error_message = '操作失败: ' . $e->getMessage();
    }
    $action = 'list';
}

// 处理促销活动删除
if ($action === 'delete' && isset($_GET['id'])) {
    $id = intval($_GET['id']);
    try {
        // 判断是否为优惠券模式
        $is_coupon_mode = isset($_GET['coupon_mode']) && $_GET['coupon_mode'] == 1;
        $type_condition = $is_coupon_mode ? "type IN (1, 2, 6)" : "1=1";
        $activity_type = $is_coupon_mode ? '优惠券活动' : '营销活动';

        // 先删除活动商品关联
        $stmt = $pdo->prepare("DELETE FROM marketing_campaign_products WHERE campaign_id = ?");
        $stmt->execute([$id]);

        // 删除活动
        $stmt = $pdo->prepare("DELETE FROM marketing_campaigns WHERE id = ? AND $type_condition");
        $stmt->execute([$id]);

        if ($stmt->rowCount() > 0) {
            record_log("删除${activity_type}: ID $id");
            $success_message = "${activity_type}已删除";
        } else {
            $error_message = "${activity_type}不存在";
        }
    } catch (PDOException $e) {
        $error_message = '删除失败: ' . $e->getMessage();
    }
    $action = 'list';
}

// 处理添加/编辑提交
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_promotion'])) {
    $id = isset($_POST['id']) ? intval($_POST['id']) : 0;
    $name = isset($_POST['name']) ? trim($_POST['name']) : '';
    $type = isset($_POST['type']) ? intval($_POST['type']) : 0;
    $description = isset($_POST['description']) ? trim($_POST['description']) : '';
    $discount_type = isset($_POST['discount_type']) ? intval($_POST['discount_type']) : 1;
    $discount_value = isset($_POST['discount_value']) ? floatval($_POST['discount_value']) : 0;
    $min_amount = isset($_POST['min_amount']) ? floatval($_POST['min_amount']) : 0;
    $start_time = isset($_POST['start_time']) ? $_POST['start_time'] : '';
    $end_time = isset($_POST['end_time']) ? $_POST['end_time'] : '';
    $target_level_id = isset($_POST['target_level_id']) && $_POST['target_level_id'] > 0 ? intval($_POST['target_level_id']) : null;
    $status = isset($_POST['status']) ? 1 : 0;

    // 判断是否为优惠券模式
    $is_coupon_mode = isset($_POST['coupon_mode']) && $_POST['coupon_mode'] == 1;

    // 商品ID列表
    $product_ids = isset($_POST['product_ids']) ? array_filter($_POST['product_ids']) : [];
    $product_prices = isset($_POST['product_prices']) ? $_POST['product_prices'] : [];
    $is_gifts = isset($_POST['is_gifts']) ? $_POST['is_gifts'] : [];

    // 表单验证
    $valid_types = $is_coupon_mode ? [1, 2, 6] : [3, 4, 5, 6];
    if (empty($name) || !in_array($type, $valid_types) || $discount_value <= 0 || empty($start_time) || empty($end_time)) {
        $error_message = '请填写所有必填字段';
        if (!in_array($type, $valid_types)) {
            $error_message = $is_coupon_mode ? '请选择优惠券类型' : '请选择活动类型';
        }
    } else if (strtotime($end_time) <= strtotime($start_time)) {
        $error_message = '结束时间必须晚于开始时间';
    } else {
        try {
            $pdo->beginTransaction();

            if ($id > 0) {
                // 更新活动
                $stmt = $pdo->prepare("
                    UPDATE marketing_campaigns 
                    SET name = ?, type = ?, description = ?, discount_type = ?, 
                        discount_value = ?, min_amount = ?, start_time = ?, end_time = ?, 
                        status = ?, target_level_id = ?
                    WHERE id = ?
                ");
                $stmt->execute([
                    $name,
                    $type,
                    $description,
                    $discount_type,
                    $discount_value,
                    $min_amount,
                    $start_time,
                    $end_time,
                    $status,
                    $target_level_id,
                    $id
                ]);

                // 删除原有关联商品
                $stmt = $pdo->prepare("DELETE FROM marketing_campaign_products WHERE campaign_id = ?");
                $stmt->execute([$id]);

                record_log("更新营销活动: $name");
                $success_message = '营销活动更新成功';
            } else {
                // 添加新活动
                $stmt = $pdo->prepare("
                    INSERT INTO marketing_campaigns 
                    (name, type, description, discount_type, discount_value, min_amount, 
                     start_time, end_time, status, target_level_id, create_time)
                    VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, NOW())
                ");
                $stmt->execute([
                    $name,
                    $type,
                    $description,
                    $discount_type,
                    $discount_value,
                    $min_amount,
                    $start_time,
                    $end_time,
                    $status,
                    $target_level_id
                ]);

                $id = $pdo->lastInsertId();
                record_log("添加营销活动: $name");
                $success_message = '营销活动添加成功';
            }

            // 添加关联商品
            if (!empty($product_ids) && in_array($type, [1, 2, 3, 4])) {
                $stmt = $pdo->prepare("
                    INSERT INTO marketing_campaign_products 
                    (campaign_id, product_id, discount_price, is_gift)
                    VALUES (?, ?, ?, ?)
                ");

                foreach ($product_ids as $key => $product_id) {
                    $discount_price = isset($product_prices[$key]) ? floatval($product_prices[$key]) : 0;
                    $is_gift = isset($is_gifts[$key]) && $is_gifts[$key] == 1 ? 1 : 0;
                    $stmt->execute([$id, $product_id, $discount_price, $is_gift]);
                }
            }

            $pdo->commit();
            $action = 'list'; // 返回列表页
        } catch (PDOException $e) {
            $pdo->rollBack();
            $error_message = ($id > 0 ? '更新' : '添加') . '营销活动失败: ' . $e->getMessage();
        }
    }
}

// 编辑活动时获取现有数据
$promotion = null;
$promotion_products = [];

if (($action === 'edit' || $action === 'view') && isset($_GET['id'])) {
    $id = intval($_GET['id']);

    // 判断是否为优惠券模式
    $is_coupon_mode = isset($_GET['coupon_mode']) && $_GET['coupon_mode'] == 1;
    $type_condition = $is_coupon_mode ? "type IN (1, 2, 6)" : "1=1";

    // 获取活动信息
    $stmt = $pdo->prepare("SELECT * FROM marketing_campaigns WHERE id = ? AND $type_condition");
    $stmt->execute([$id]);
    $promotion = $stmt->fetch();

    if (!$promotion) {
        $error_message = $is_coupon_mode ? '优惠券活动不存在' : '营销活动不存在或不是促销类型';
        $action = 'list';
    } else {
        // 获取关联商品
        $stmt = $pdo->prepare("
            SELECT cp.*, p.name as product_name, p.price as product_price
            FROM marketing_campaign_products cp
            JOIN products p ON cp.product_id = p.id
            WHERE cp.campaign_id = ?
        ");
        $stmt->execute([$id]);
        $promotion_products = $stmt->fetchAll();
    }
} else if ($action === 'add') {
    // 预设活动类型（如果有）
    $preset_type = isset($_GET['preset_type']) ? intval($_GET['preset_type']) : 0;
    if ($preset_type > 0) {
        $promotion = [
            'type' => $preset_type,
            'status' => 1,
            'discount_type' => ($preset_type == 1) ? 1 : 2, // 默认满减券为固定金额，折扣券为百分比
        ];
    } else {
        $promotion = [];
    }
}

// 获取商品列表
$stmt = $pdo->query("SELECT id, name, price FROM products WHERE status = 1 ORDER BY id");
$products = $stmt->fetchAll();

// 获取会员等级列表
$stmt = $pdo->query("SELECT id, level_name FROM member_levels ORDER BY min_points");
$member_levels = $stmt->fetchAll();

// 筛选促销活动列表
$filter_type = isset($_GET['type']) ? intval($_GET['type']) : 0;
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : -1;

// 判断是否为优惠券模式
$is_coupon_mode = isset($_GET['coupon_mode']) && $_GET['coupon_mode'] == 1;
// 不再限制类型，查询所有类型的活动
$type_condition = "1=1";

$where = [$type_condition]; // 显示所有类型的活动
$params = [];

if ($filter_type > 0) {
    $where[] = "type = ?";
    $params[] = $filter_type;
}

if ($filter_status != -1) {
    $where[] = "status = ?";
    $params[] = $filter_status;
}

$where_clause = implode(" AND ", $where);

// 分页参数
$page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
$limit = 10;
$offset = ($page - 1) * $limit;

// 获取总记录数
$count_sql = "SELECT COUNT(*) AS total FROM marketing_campaigns WHERE $where_clause";
$stmt = $pdo->prepare($count_sql);
$stmt->execute($params);
$total_records = $stmt->fetch()['total'];
$total_pages = ceil($total_records / $limit);

// 获取分页数据
$sql = "SELECT * FROM marketing_campaigns WHERE $where_clause ORDER BY id DESC LIMIT $offset, $limit";
$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$promotions = $stmt->fetchAll();

// 获取当前活动的关联商品
function get_promotion_products($pdo, $promotion_id)
{
    $stmt = $pdo->prepare("
        SELECT cp.*, p.name as product_name
        FROM marketing_campaign_products cp
        JOIN products p ON cp.product_id = p.id
        WHERE cp.campaign_id = ?
    ");
    $stmt->execute([$promotion_id]);
    return $stmt->fetchAll();
}

// 活动类型名称
function get_promotion_type_name($type)
{
    $types = [
        1 => '满减券',
        2 => '折扣券',
        3 => '限时优惠',
        4 => '套餐促销',
        5 => '充值送礼',
        6 => '节日促销/优惠券',
        7 => '推荐返利'
    ];
    return $types[$type] ?? '未知类型';
}

// 确定页面标题和模式
$is_coupon_mode = isset($_GET['coupon_mode']) && $_GET['coupon_mode'] == 1;
$page_title = $is_coupon_mode ? "优惠券活动" : "营销活动管理";
$action_title = $action === 'add' ? "添加" : "编辑";
$form_title = $is_coupon_mode ? ($action === 'add' ? "创建优惠券活动" : "编辑优惠券活动") : ($action === 'add' ? "添加营销活动" : "编辑营销活动");
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $page_title; ?></title>
    <link rel="stylesheet" href="../style.css">
    <style>
        .product-row {
            display: flex;
            gap: 10px;
            margin-bottom: 10px;
            align-items: center;
        }

        #productContainer {
            margin-top: 10px;
        }

        .view-products {
            margin-top: 10px;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2><?php echo $page_title; ?></h2>
            <div class="breadcrumb">
                <a href="index.php">营销推广</a> &gt;
                <?php if ($is_coupon_mode): ?>
                    <a href="coupon.php">优惠券管理</a> &gt;
                    <span><?php echo $action_title; ?>优惠券活动</span>
                <?php else: ?>
                    <span>营销活动</span>
                <?php endif; ?>
            </div>
        </div>

        <div class="content">
            <?php if (!empty($success_message)): ?>
                <div class="alert alert-success"><?php echo $success_message; ?></div>
            <?php endif; ?>

            <?php if (!empty($error_message)): ?>
                <div class="alert alert-danger"><?php echo $error_message; ?></div>
            <?php endif; ?>

            <?php if ($action === 'list'): ?>
                <!-- 操作栏 -->
                <div class="action-bar">
                    <?php if ($is_coupon_mode): ?>
                        <a href="?action=add&coupon_mode=1" class="btn btn-primary">添加优惠券活动</a>
                    <?php else: ?>
                        <a href="?action=add" class="btn btn-primary">添加营销活动</a>
                    <?php endif; ?>
                </div>

                <!-- 筛选表单 -->
                <form method="get" action="" class="filter-form">
                    <?php if ($is_coupon_mode): ?>
                        <input type="hidden" name="coupon_mode" value="1">
                    <?php endif; ?>
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="type">活动类型</label>
                            <select id="type" name="type">
                                <option value="0">全部类型</option>
                                <?php if ($is_coupon_mode): ?>
                                    <option value="1" <?php echo $filter_type == 1 ? 'selected' : ''; ?>>满减券</option>
                                    <option value="2" <?php echo $filter_type == 2 ? 'selected' : ''; ?>>折扣券</option>
                                    <option value="6" <?php echo $filter_type == 6 ? 'selected' : ''; ?>>节日优惠券</option>
                                <?php else: ?>
                                    <option value="1" <?php echo $filter_type == 1 ? 'selected' : ''; ?>>满减券</option>
                                    <option value="2" <?php echo $filter_type == 2 ? 'selected' : ''; ?>>折扣券</option>
                                    <option value="3" <?php echo $filter_type == 3 ? 'selected' : ''; ?>>限时优惠</option>
                                    <option value="4" <?php echo $filter_type == 4 ? 'selected' : ''; ?>>套餐促销</option>
                                    <option value="5" <?php echo $filter_type == 5 ? 'selected' : ''; ?>>充值送礼</option>
                                    <option value="6" <?php echo $filter_type == 6 ? 'selected' : ''; ?>>节日促销</option>
                                <?php endif; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="status">状态</label>
                            <select id="status" name="status">
                                <option value="-1">全部状态</option>
                                <option value="1" <?php echo $filter_status == 1 ? 'selected' : ''; ?>>启用</option>
                                <option value="0" <?php echo $filter_status == 0 ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>
                        <div class="filter-item" style="display: flex; align-items: flex-end;">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="?action=list<?php echo $is_coupon_mode ? '&coupon_mode=1' : ''; ?>" class="btn btn-secondary" style="margin-left: 10px;">重置</a>
                        </div>
                    </div>
                </form>

                <!-- 促销活动列表 -->
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>活动名称</th>
                                <th>活动类型</th>
                                <th>优惠内容</th>
                                <th>会员等级</th>
                                <th>有效期</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($promotions) > 0): ?>
                                <?php foreach ($promotions as $promotion): ?>
                                    <tr>
                                        <td><?php echo $promotion['id']; ?></td>
                                        <td><?php echo htmlspecialchars($promotion['name']); ?></td>
                                        <td><?php echo get_promotion_type_name($promotion['type']); ?></td>
                                        <td>
                                            <?php
                                            if ($promotion['discount_type'] == 1) {
                                                if ($promotion['type'] == 5) { // 充值送礼
                                                    echo "充值满{$promotion['min_amount']}送{$promotion['discount_value']}";
                                                } else {
                                                    echo "满{$promotion['min_amount']}减{$promotion['discount_value']}";
                                                }
                                            } else {
                                                echo ($promotion['discount_value'] * 10) . "折";
                                            }
                                            ?>
                                        </td>
                                        <td>
                                            <?php
                                            if ($promotion['target_level_id']) {
                                                $level_name = '';
                                                foreach ($member_levels as $level) {
                                                    if ($level['id'] == $promotion['target_level_id']) {
                                                        $level_name = $level['level_name'];
                                                        break;
                                                    }
                                                }
                                                echo $level_name;
                                            } else {
                                                echo "所有会员";
                                            }
                                            ?>
                                        </td>
                                        <td><?php echo $promotion['start_time'] ? substr($promotion['start_time'], 0, 16) : '-'; ?> - <?php echo $promotion['end_time'] ? substr($promotion['end_time'], 0, 16) : '-'; ?></td>
                                        <td>
                                            <?php if ($promotion['status'] == 1): ?>
                                                <span class="status-active">启用</span>
                                            <?php else: ?>
                                                <span class="status-inactive">禁用</span>
                                            <?php endif; ?>
                                        </td>
                                        <td>
                                            <a href="?action=view&id=<?php echo $promotion['id']; ?><?php echo $is_coupon_mode ? '&coupon_mode=1' : ''; ?>" class="btn btn-sm btn-secondary">查看</a>
                                            <a href="?action=edit&id=<?php echo $promotion['id']; ?><?php echo $is_coupon_mode ? '&coupon_mode=1' : ''; ?>" class="btn btn-sm btn-primary">编辑</a>
                                            <a href="?action=toggle_status&id=<?php echo $promotion['id']; ?><?php echo $is_coupon_mode ? '&coupon_mode=1' : ''; ?>"
                                                class="btn btn-sm <?php echo $promotion['status'] == 1 ? 'btn-danger' : 'btn-success'; ?>">
                                                <?php echo $promotion['status'] == 1 ? '禁用' : '启用'; ?>
                                            </a>
                                            <a href="?action=delete&id=<?php echo $promotion['id']; ?><?php echo $is_coupon_mode ? '&coupon_mode=1' : ''; ?>" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此<?php echo $is_coupon_mode ? '优惠券活动' : '营销活动'; ?>吗？');">删除</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无营销活动数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 分页 -->
                <?php if ($total_pages > 1): ?>
                    <div class="pagination">
                        <?php if ($page > 1): ?>
                            <a href="?page=1&type=<?php echo $filter_type; ?>&status=<?php echo $filter_status; ?><?php echo $is_coupon_mode ? '&coupon_mode=1' : ''; ?>" class="page-link">首页</a>
                            <a href="?page=<?php echo $page - 1; ?>&type=<?php echo $filter_type; ?>&status=<?php echo $filter_status; ?><?php echo $is_coupon_mode ? '&coupon_mode=1' : ''; ?>" class="page-link">上一页</a>
                        <?php endif; ?>

                        <?php
                        $startPage = max(1, $page - 2);
                        $endPage = min($total_pages, $page + 2);

                        for ($i = $startPage; $i <= $endPage; $i++):
                        ?>
                            <a href="?page=<?php echo $i; ?>&type=<?php echo $filter_type; ?>&status=<?php echo $filter_status; ?><?php echo $is_coupon_mode ? '&coupon_mode=1' : ''; ?>" class="page-link <?php echo $i == $page ? 'current' : ''; ?>"><?php echo $i; ?></a>
                        <?php endfor; ?>

                        <?php if ($page < $total_pages): ?>
                            <a href="?page=<?php echo $page + 1; ?>&type=<?php echo $filter_type; ?>&status=<?php echo $filter_status; ?><?php echo $is_coupon_mode ? '&coupon_mode=1' : ''; ?>" class="page-link">下一页</a>
                            <a href="?page=<?php echo $total_pages; ?>&type=<?php echo $filter_type; ?>&status=<?php echo $filter_status; ?><?php echo $is_coupon_mode ? '&coupon_mode=1' : ''; ?>" class="page-link">末页</a>
                        <?php endif; ?>
                    </div>
                    <div class="pagination-info">
                        共 <?php echo $total_records; ?> 条记录，当前 <?php echo $page; ?>/<?php echo $total_pages; ?> 页
                    </div>
                <?php endif; ?>
            <?php elseif ($action === 'add' || $action === 'edit'): ?>
                <div class="form-container">
                    <h3><?php echo $form_title; ?></h3>
                    <form method="post" action="">
                        <?php if ($action === 'edit' && $promotion): ?>
                            <input type="hidden" name="id" value="<?php echo $promotion['id']; ?>">
                        <?php endif; ?>

                        <?php if ($is_coupon_mode): ?>
                            <input type="hidden" name="coupon_mode" value="1">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="name"><?php echo $is_coupon_mode ? "优惠券名称" : "活动名称"; ?> <span class="text-danger">*</span></label>
                            <input type="text" id="name" name="name" value="<?php echo htmlspecialchars($promotion['name'] ?? ''); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="type"><?php echo $is_coupon_mode ? "优惠券类型" : "活动类型"; ?> <span class="text-danger">*</span></label>
                            <?php if ($action === 'edit' && isset($promotion['type'])): ?>
                                <!-- 编辑时不允许修改类型，只显示 -->
                                <input type="hidden" name="type" value="<?php echo $promotion['type']; ?>">
                                <input type="text" class="form-control" value="<?php echo get_promotion_type_name($promotion['type']); ?>" readonly>
                            <?php else: ?>
                                <!-- 添加新活动时允许选择类型 -->
                                <select id="type" name="type" required onchange="handleTypeChange()">
                                    <?php if ($is_coupon_mode): ?>
                                        <option value="">-- 请选择优惠券类型 --</option>
                                        <option value="1" <?php echo isset($promotion['type']) && $promotion['type'] == 1 ? 'selected' : ''; ?>>满减券</option>
                                        <option value="2" <?php echo isset($promotion['type']) && $promotion['type'] == 2 ? 'selected' : ''; ?>>折扣券</option>
                                        <option value="6" <?php echo isset($promotion['type']) && $promotion['type'] == 6 ? 'selected' : ''; ?>>节日优惠券</option>
                                    <?php else: ?>
                                        <option value="">-- 请选择活动类型 --</option>
                                        <option value="1" <?php echo isset($promotion['type']) && $promotion['type'] == 1 ? 'selected' : ''; ?>>满减券</option>
                                        <option value="2" <?php echo isset($promotion['type']) && $promotion['type'] == 2 ? 'selected' : ''; ?>>折扣券</option>
                                        <option value="3" <?php echo isset($promotion['type']) && $promotion['type'] == 3 ? 'selected' : ''; ?>>限时优惠</option>
                                        <option value="4" <?php echo isset($promotion['type']) && $promotion['type'] == 4 ? 'selected' : ''; ?>>套餐促销</option>
                                        <option value="5" <?php echo isset($promotion['type']) && $promotion['type'] == 5 ? 'selected' : ''; ?>>充值送礼</option>
                                        <option value="6" <?php echo isset($promotion['type']) && $promotion['type'] == 6 ? 'selected' : ''; ?>>节日促销</option>
                                    <?php endif; ?>
                                </select>
                            <?php endif; ?>
                        </div>

                        <div class="form-group">
                            <label for="description">活动描述</label>
                            <textarea id="description" name="description" rows="3"><?php echo htmlspecialchars($promotion['description'] ?? ''); ?></textarea>
                        </div>

                        <div class="form-group">
                            <label for="discount_type">优惠类型 <span class="text-danger">*</span></label>
                            <select id="discount_type" name="discount_type" required>
                                <option value="1" <?php echo isset($promotion['discount_type']) && $promotion['discount_type'] == 1 ? 'selected' : ''; ?>>固定金额</option>
                                <option value="2" <?php echo isset($promotion['discount_type']) && $promotion['discount_type'] == 2 ? 'selected' : ''; ?>>百分比折扣</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="discount_value">优惠值 <span class="text-danger">*</span></label>
                            <input type="number" id="discount_value" name="discount_value" step="0.01" min="0" value="<?php echo $promotion['discount_value'] ?? ''; ?>" required>
                            <small id="discount_hint"></small>
                        </div>

                        <div class="form-group">
                            <label for="min_amount">最低消费金额</label>
                            <input type="number" id="min_amount" name="min_amount" step="0.01" min="0" value="<?php echo $promotion['min_amount'] ?? '0'; ?>">
                        </div>

                        <div class="form-group">
                            <label for="start_time">开始时间 <span class="text-danger">*</span></label>
                            <input type="datetime-local" id="start_time" name="start_time" value="<?php echo isset($promotion['start_time']) ? date('Y-m-d\TH:i', strtotime($promotion['start_time'])) : date('Y-m-d\TH:i'); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="end_time">结束时间 <span class="text-danger">*</span></label>
                            <input type="datetime-local" id="end_time" name="end_time" value="<?php echo isset($promotion['end_time']) ? date('Y-m-d\TH:i', strtotime($promotion['end_time'])) : date('Y-m-d\TH:i', strtotime('+30 days')); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="target_level_id">适用会员等级</label>
                            <select id="target_level_id" name="target_level_id">
                                <option value="">所有会员</option>
                                <?php foreach ($member_levels as $level): ?>
                                    <option value="<?php echo $level['id']; ?>" <?php echo isset($promotion['target_level_id']) && $promotion['target_level_id'] == $level['id'] ? 'selected' : ''; ?>><?php echo htmlspecialchars($level['level_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="status">状态</label>
                            <div class="checkbox-item">
                                <label>
                                    <input type="checkbox" id="status" name="status" value="1" <?php echo !isset($promotion['status']) || $promotion['status'] == 1 ? 'checked' : ''; ?>> 启用
                                </label>
                            </div>
                        </div>

                        <div id="product_section" <?php echo (!isset($promotion['type']) || !in_array($promotion['type'], [1, 2, 3, 4])) ? 'style="display:none;"' : ''; ?>>
                            <h4>关联商品</h4>
                            <div id="productContainer">
                                <?php if (!empty($promotion_products)): ?>
                                    <?php foreach ($promotion_products as $index => $prod): ?>
                                        <div class="product-row">
                                            <div style="flex: 3;">
                                                <select name="product_ids[]" class="product-select">
                                                    <option value="">-- 选择商品 --</option>
                                                    <?php foreach ($products as $product): ?>
                                                        <option value="<?php echo $product['id']; ?>" <?php echo $prod['product_id'] == $product['id'] ? 'selected' : ''; ?>>
                                                            <?php echo htmlspecialchars($product['name']); ?> (￥<?php echo $product['price']; ?>)
                                                        </option>
                                                    <?php endforeach; ?>
                                                </select>
                                            </div>
                                            <div style="flex: 1;">
                                                <input type="number" name="product_prices[]" placeholder="促销价格" step="0.01" min="0" value="<?php echo $prod['discount_price']; ?>">
                                            </div>
                                            <div style="flex: 1;" class="checkbox-item">
                                                <label>
                                                    <input type="checkbox" name="is_gifts[]" value="<?php echo $index; ?>" <?php echo $prod['is_gift'] == 1 ? 'checked' : ''; ?>> 赠品
                                                </label>
                                            </div>
                                            <div>
                                                <button type="button" class="btn btn-sm btn-danger" onclick="removeProduct(this)">删除</button>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <div class="product-row">
                                        <div style="flex: 3;">
                                            <select name="product_ids[]" class="product-select">
                                                <option value="">-- 选择商品 --</option>
                                                <?php foreach ($products as $product): ?>
                                                    <option value="<?php echo $product['id']; ?>">
                                                        <?php echo htmlspecialchars($product['name']); ?> (￥<?php echo $product['price']; ?>)
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        </div>
                                        <div style="flex: 1;">
                                            <input type="number" name="product_prices[]" placeholder="促销价格" step="0.01" min="0">
                                        </div>
                                        <div style="flex: 1;" class="checkbox-item">
                                            <label>
                                                <input type="checkbox" name="is_gifts[]" value="0"> 赠品
                                            </label>
                                        </div>
                                        <div>
                                            <button type="button" class="btn btn-sm btn-danger" onclick="removeProduct(this)">删除</button>
                                        </div>
                                    </div>
                                <?php endif; ?>
                            </div>
                            <button type="button" class="btn btn-secondary" onclick="addProduct()">添加商品</button>
                        </div>

                        <div class="form-actions" style="margin-top: 20px;">
                            <button type="submit" name="save_promotion" class="btn btn-primary"><?php echo $action === 'add' ? ($is_coupon_mode ? '创建' : '添加') : '保存'; ?></button>
                            <a href="<?php echo $is_coupon_mode ? 'coupon.php' : '?action=list'; ?>" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($action === 'view'): ?>
                <div class="form-container">
                    <h3><?php echo $is_coupon_mode ? "优惠券活动详情" : "营销活动详情"; ?></h3>
                    <table class="info-table">
                        <tr>
                            <td width="20%"><?php echo $is_coupon_mode ? "优惠券名称：" : "活动名称："; ?></td>
                            <td><?php echo htmlspecialchars($promotion['name']); ?></td>
                        </tr>
                        <tr>
                            <td><?php echo $is_coupon_mode ? "优惠券类型：" : "活动类型："; ?></td>
                            <td><?php echo get_promotion_type_name($promotion['type']); ?></td>
                        </tr>
                        <tr>
                            <td>优惠内容：</td>
                            <td>
                                <?php
                                if ($promotion['discount_type'] == 1) {
                                    if ($promotion['type'] == 5) { // 充值送礼
                                        echo "充值满{$promotion['min_amount']}送{$promotion['discount_value']}";
                                    } else {
                                        echo "满{$promotion['min_amount']}减{$promotion['discount_value']}";
                                    }
                                } else {
                                    echo ($promotion['discount_value'] * 10) . "折";
                                }
                                ?>
                            </td>
                        </tr>
                        <tr>
                            <td>活动描述：</td>
                            <td><?php echo htmlspecialchars($promotion['description'] ?: '无'); ?></td>
                        </tr>
                        <tr>
                            <td>有效期：</td>
                            <td><?php echo substr($promotion['start_time'], 0, 16); ?> 至 <?php echo substr($promotion['end_time'], 0, 16); ?></td>
                        </tr>
                        <tr>
                            <td>适用会员：</td>
                            <td>
                                <?php
                                if ($promotion['target_level_id']) {
                                    $level_name = '';
                                    foreach ($member_levels as $level) {
                                        if ($level['id'] == $promotion['target_level_id']) {
                                            $level_name = $level['level_name'];
                                            break;
                                        }
                                    }
                                    echo $level_name;
                                } else {
                                    echo "所有会员";
                                }
                                ?>
                            </td>
                        </tr>
                        <tr>
                            <td>状态：</td>
                            <td><?php echo $promotion['status'] == 1 ? '<span class="status-active">启用</span>' : '<span class="status-inactive">禁用</span>'; ?></td>
                        </tr>
                    </table>

                    <?php if (in_array($promotion['type'], [1, 2, 3, 4]) && !empty($promotion_products)): ?>
                        <div class="view-products">
                            <h3>关联商品</h3>
                            <table class="data-table">
                                <thead>
                                    <tr>
                                        <th>商品名称</th>
                                        <th>原价</th>
                                        <th>促销价</th>
                                        <th>是否赠品</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($promotion_products as $product): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($product['product_name']); ?></td>
                                            <td>￥<?php echo number_format($product['product_price'], 2); ?></td>
                                            <td>￥<?php echo number_format($product['discount_price'], 2); ?></td>
                                            <td><?php echo $product['is_gift'] == 1 ? '是' : '否'; ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>

                    <div class="form-actions">
                        <a href="?action=edit&id=<?php echo $promotion['id']; ?><?php echo $is_coupon_mode ? '&coupon_mode=1' : ''; ?>" class="btn btn-primary">编辑</a>
                        <a href="?action=list<?php echo $is_coupon_mode ? '&coupon_mode=1' : ''; ?>" class="btn btn-secondary">返回列表</a>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // 初始化优惠类型提示
            updateDiscountHint();

            // 绑定优惠类型变更事件
            document.getElementById('discount_type').addEventListener('change', updateDiscountHint);

            // 绑定活动类型变更事件
            if (document.getElementById('type')) {
                document.getElementById('type').addEventListener('change', handleTypeChange);
            }

            // 编辑模式下也需要初始化显示商品部分
            <?php if ($action === 'edit' && isset($promotion['type'])): ?>
                const typeValue = '<?php echo $promotion['type']; ?>';
                const productSection = document.getElementById('product_section');

                // 满减券、折扣券、限时优惠和套餐促销需要关联商品
                if (typeValue == '1' || typeValue == '2' || typeValue == '3' || typeValue == '4') {
                    if (productSection) productSection.style.display = 'block';
                } else {
                    if (productSection) productSection.style.display = 'none';
                }
            <?php endif; ?>
        });

        // 更新优惠值提示
        function updateDiscountHint() {
            const discountType = document.getElementById('discount_type').value;
            const hintElement = document.getElementById('discount_hint');

            if (discountType == '1') {
                hintElement.textContent = '输入减免的具体金额';
            } else {
                hintElement.textContent = '输入折扣值，如0.8表示8折';
            }
        }

        // 处理活动类型变更
        function handleTypeChange() {
            const typeValue = document.getElementById('type').value;
            const productSection = document.getElementById('product_section');

            // 满减券、折扣券、限时优惠和套餐促销需要关联商品
            if (typeValue == '1' || typeValue == '2' || typeValue == '3' || typeValue == '4') {
                productSection.style.display = 'block';
            } else {
                productSection.style.display = 'none';
            }
        }

        // 添加商品行
        function addProduct() {
            const container = document.getElementById('productContainer');
            const productCount = container.querySelectorAll('.product-row').length;

            const row = document.createElement('div');
            row.className = 'product-row';

            // 复制第一行的HTML结构并替换索引
            const firstRow = container.querySelector('.product-row');
            row.innerHTML = firstRow.innerHTML;

            // 重置新行的值
            row.querySelector('select').value = '';
            if (row.querySelector('input[type="number"]')) {
                row.querySelector('input[type="number"]').value = '';
            }

            // 更新赠品复选框的值
            const checkbox = row.querySelector('input[type="checkbox"]');
            if (checkbox) {
                checkbox.checked = false;
                checkbox.value = productCount;
            }

            container.appendChild(row);
        }

        // 删除商品行
        function removeProduct(button) {
            const row = button.closest('.product-row');
            const container = document.getElementById('productContainer');

            // 至少保留一行
            if (container.querySelectorAll('.product-row').length > 1) {
                row.remove();

                // 更新剩余行的索引
                const checkboxes = container.querySelectorAll('input[name="is_gifts[]"]');
                checkboxes.forEach((checkbox, index) => {
                    checkbox.value = index;
                });
            }
        }
    </script>
</body>

</html>