<?php
// member/info.php - 会员信息管理
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('member.view');

// 处理操作请求
$action = isset($_GET['action']) ? $_GET['action'] : 'list';
$message = '';
$messageType = '';

// 获取会员等级列表
$stmt = $pdo->query("SELECT id, level_name, discount FROM member_levels ORDER BY min_points");
$memberLevels = $stmt->fetchAll();

// 处理会员添加
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $action === 'add') {
    // 检查添加权限
    check_permission_or_die('member.add');

    $name = $_POST['name'] ?? '';
    $phone = $_POST['phone'] ?? '';
    $birthday = !empty($_POST['birthday']) ? $_POST['birthday'] : null;
    $address = $_POST['address'] ?? '';
    $preference = $_POST['preference'] ?? '';
    $level_id = $_POST['level_id'] ?? 1;
    $status = isset($_POST['status']) ? 1 : 0;

    if (empty($name) || empty($phone)) {
        $message = '请填写必填字段: 姓名、手机号码';
        $messageType = 'danger';
    } else {
        // 检查手机号是否已存在
        $stmt = $pdo->prepare("SELECT id FROM members WHERE phone = ?");
        $stmt->execute([$phone]);
        if ($stmt->fetch()) {
            $message = '该手机号已注册，请使用其他手机号';
            $messageType = 'danger';
        } else {
            try {
                $stmt = $pdo->prepare("INSERT INTO members (name, phone, birthday, address, preference, level_id, status) VALUES (?, ?, ?, ?, ?, ?, ?)");
                $stmt->execute([$name, $phone, $birthday, $address, $preference, $level_id, $status]);

                record_log("添加会员: $name ($phone)");
                $message = '会员添加成功';
                $messageType = 'success';
                $action = 'list'; // 返回列表视图
            } catch (PDOException $e) {
                $message = '会员添加失败: ' . $e->getMessage();
                $messageType = 'danger';
            }
        }
    }
}

// 处理会员更新
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $action === 'edit') {
    // 检查编辑权限
    check_permission_or_die('member.edit');

    $id = $_POST['id'] ?? 0;
    $name = $_POST['name'] ?? '';
    $phone = $_POST['phone'] ?? '';
    $birthday = !empty($_POST['birthday']) ? $_POST['birthday'] : null;
    $address = $_POST['address'] ?? '';
    $preference = $_POST['preference'] ?? '';
    $level_id = $_POST['level_id'] ?? 1;
    $status = isset($_POST['status']) ? 1 : 0;

    if (empty($id) || empty($name) || empty($phone)) {
        $message = '请填写必填字段: 姓名、手机号码';
        $messageType = 'danger';
    } else {
        // 检查手机号是否与其他会员重复
        $stmt = $pdo->prepare("SELECT id FROM members WHERE phone = ? AND id != ?");
        $stmt->execute([$phone, $id]);
        if ($stmt->fetch()) {
            $message = '该手机号已被其他会员使用，请更换手机号';
            $messageType = 'danger';
        } else {
            try {
                $stmt = $pdo->prepare("UPDATE members SET name = ?, phone = ?, birthday = ?, address = ?, preference = ?, level_id = ?, status = ? WHERE id = ?");
                $stmt->execute([$name, $phone, $birthday, $address, $preference, $level_id, $status, $id]);

                record_log("更新会员信息: $name (ID: $id)");
                $message = '会员信息更新成功';
                $messageType = 'success';
                $action = 'list'; // 返回列表视图
            } catch (PDOException $e) {
                $message = '会员信息更新失败: ' . $e->getMessage();
                $messageType = 'danger';
            }
        }
    }
}

// 处理会员删除
if ($action === 'delete' && isset($_GET['id'])) {
    // 检查删除权限
    check_permission_or_die('member.delete');

    $id = $_GET['id'];

    try {
        // 先删除会员相关的积分和充值记录
        $pdo->beginTransaction();

        $stmt = $pdo->prepare("DELETE FROM member_points_log WHERE member_id = ?");
        $stmt->execute([$id]);

        $stmt = $pdo->prepare("DELETE FROM member_recharge_log WHERE member_id = ?");
        $stmt->execute([$id]);

        // 最后删除会员
        $stmt = $pdo->prepare("DELETE FROM members WHERE id = ?");
        $stmt->execute([$id]);

        $pdo->commit();

        record_log("删除会员 (ID: $id)");
        $message = '会员删除成功';
        $messageType = 'success';
    } catch (PDOException $e) {
        $pdo->rollBack();
        $message = '会员删除失败: ' . $e->getMessage();
        $messageType = 'danger';
    }
    $action = 'list'; // 返回列表视图
}

// 获取单个会员信息（用于编辑和查看）
$memberInfo = null;
if (($action === 'edit' || $action === 'view') && isset($_GET['id'])) {
    $id = $_GET['id'];
    try {
        $stmt = $pdo->prepare("SELECT m.*, l.level_name FROM members m LEFT JOIN member_levels l ON m.level_id = l.id WHERE m.id = ?");
        $stmt->execute([$id]);
        $memberInfo = $stmt->fetch();

        if (!$memberInfo) {
            $message = '会员不存在';
            $messageType = 'danger';
            $action = 'list'; // 返回列表视图
        }
    } catch (PDOException $e) {
        $message = '获取会员信息失败: ' . $e->getMessage();
        $messageType = 'danger';
        $action = 'list'; // 返回列表视图
    }
}

// 获取会员列表（用于列表视图）
$members = [];
if ($action === 'list') {
    // 分页参数
    $page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
    $limit = 10;
    $offset = ($page - 1) * $limit;

    // 搜索条件
    $searchName = isset($_GET['search_name']) ? $_GET['search_name'] : '';
    $searchPhone = isset($_GET['search_phone']) ? $_GET['search_phone'] : '';
    $searchLevel = isset($_GET['search_level']) ? $_GET['search_level'] : '';
    $searchStatus = isset($_GET['search_status']) ? $_GET['search_status'] : '';

    $where = [];
    $params = [];

    if (!empty($searchName)) {
        $where[] = "m.name LIKE ?";
        $params[] = "%$searchName%";
    }

    if (!empty($searchPhone)) {
        $where[] = "m.phone LIKE ?";
        $params[] = "%$searchPhone%";
    }

    if (!empty($searchLevel)) {
        $where[] = "m.level_id = ?";
        $params[] = $searchLevel;
    }

    if ($searchStatus !== '') {
        $where[] = "m.status = ?";
        $params[] = $searchStatus;
    }

    $whereClause = empty($where) ? "" : "WHERE " . implode(" AND ", $where);

    // 获取总记录数
    $countSql = "SELECT COUNT(*) as total FROM members m $whereClause";
    $stmt = $pdo->prepare($countSql);
    $stmt->execute($params);
    $totalRecords = $stmt->fetch()['total'];
    $totalPages = ceil($totalRecords / $limit);

    // 获取分页数据
    $sql = "SELECT m.*, l.level_name FROM members m
            LEFT JOIN member_levels l ON m.level_id = l.id
            $whereClause
            ORDER BY m.id DESC LIMIT $offset, $limit";
    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $members = $stmt->fetchAll();
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>会员信息管理 - FloraEase</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>会员信息管理</h2>
            <div class="breadcrumb">
                <a href="index.php">会员管理</a> / 会员信息
            </div>
        </div>

        <div class="content">
            <?php if (!empty($message)): ?>
                <div class="alert alert-<?php echo $messageType; ?>">
                    <?php echo $message; ?>
                </div>
            <?php endif; ?>

            <?php if ($action === 'list'): ?>
                <!-- 操作栏 -->
                <div class="action-bar">
                    <?php if (has_permission('member.add')): ?>
                        <a href="?action=add" class="btn btn-primary">添加会员</a>
                    <?php endif; ?>
                </div>

                <!-- 搜索表单 -->
                <form method="get" action="info.php" class="filter-form">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="search_name">会员姓名</label>
                            <input type="text" id="search_name" name="search_name" value="<?php echo htmlspecialchars($searchName ?? ''); ?>">
                        </div>
                        <div class="filter-item">
                            <label for="search_phone">手机号码</label>
                            <input type="text" id="search_phone" name="search_phone" value="<?php echo htmlspecialchars($searchPhone ?? ''); ?>">
                        </div>
                        <div class="filter-item">
                            <label for="search_level">会员等级</label>
                            <select id="search_level" name="search_level">
                                <option value="">全部等级</option>
                                <?php foreach ($memberLevels as $level): ?>
                                    <option value="<?php echo $level['id']; ?>" <?php echo $searchLevel == $level['id'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($level['level_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="search_status">状态</label>
                            <select id="search_status" name="search_status">
                                <option value="">全部</option>
                                <option value="1" <?php echo $searchStatus === '1' ? 'selected' : ''; ?>>启用</option>
                                <option value="0" <?php echo $searchStatus === '0' ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>
                    </div>
                    <div class="filter-buttons">
                        <button type="submit" class="btn btn-primary">搜索</button>
                        <a href="?action=list" class="btn btn-secondary">重置</a>
                    </div>
                </form>

                <!-- 会员列表 -->
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>姓名</th>
                                <th>手机号码</th>
                                <th>会员等级</th>
                                <th>积分</th>
                                <th>储值余额</th>
                                <th>状态</th>
                                <th>注册时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($members as $member): ?>
                                <tr>
                                    <td><?php echo $member['id']; ?></td>
                                    <td><?php echo htmlspecialchars($member['name']); ?></td>
                                    <td><?php echo htmlspecialchars($member['phone']); ?></td>
                                    <td><?php echo htmlspecialchars($member['level_name']); ?></td>
                                    <td><?php echo $member['points']; ?></td>
                                    <td>￥<?php echo number_format($member['balance'], 2); ?></td>
                                    <td>
                                        <?php if ($member['status'] == 1): ?>
                                            <span class="status-active">启用</span>
                                        <?php else: ?>
                                            <span class="status-inactive">禁用</span>
                                        <?php endif; ?>
                                    </td>
                                    <td><?php echo $member['create_time']; ?></td>
                                    <td>
                                        <a href="?action=view&id=<?php echo $member['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                        <?php if (has_permission('member.edit')): ?>
                                            <a href="?action=edit&id=<?php echo $member['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                        <?php endif; ?>
                                        <?php if (has_permission('member.delete')): ?>
                                            <a href="?action=delete&id=<?php echo $member['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此会员吗？相关的积分和充值记录也将被删除!')">删除</a>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                            <?php if (empty($members)): ?>
                                <tr>
                                    <td colspan="9" class="text-center">暂无会员数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 分页 -->
                <?php if ($totalPages > 1): ?>
                    <div class="pagination">
                        <?php if ($page > 1): ?>
                            <a href="?action=list&page=1<?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchPhone) ? '&search_phone=' . urlencode($searchPhone) : ''; ?><?php echo !empty($searchLevel) ? '&search_level=' . $searchLevel : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link">首页</a>
                            <a href="?action=list&page=<?php echo $page - 1; ?><?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchPhone) ? '&search_phone=' . urlencode($searchPhone) : ''; ?><?php echo !empty($searchLevel) ? '&search_level=' . $searchLevel : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link">上一页</a>
                        <?php endif; ?>

                        <?php
                        $startPage = max(1, $page - 2);
                        $endPage = min($totalPages, $page + 2);

                        for ($i = $startPage; $i <= $endPage; $i++):
                        ?>
                            <a href="?action=list&page=<?php echo $i; ?><?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchPhone) ? '&search_phone=' . urlencode($searchPhone) : ''; ?><?php echo !empty($searchLevel) ? '&search_level=' . $searchLevel : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link <?php echo $i == $page ? 'current' : ''; ?>"><?php echo $i; ?></a>
                        <?php endfor; ?>

                        <?php if ($page < $totalPages): ?>
                            <a href="?action=list&page=<?php echo $page + 1; ?><?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchPhone) ? '&search_phone=' . urlencode($searchPhone) : ''; ?><?php echo !empty($searchLevel) ? '&search_level=' . $searchLevel : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link">下一页</a>
                            <a href="?action=list&page=<?php echo $totalPages; ?><?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchPhone) ? '&search_phone=' . urlencode($searchPhone) : ''; ?><?php echo !empty($searchLevel) ? '&search_level=' . $searchLevel : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link">末页</a>
                        <?php endif; ?>
                    </div>
                    <div class="pagination-info">
                        共 <?php echo $totalRecords; ?> 条记录，当前 <?php echo $page; ?>/<?php echo $totalPages; ?> 页
                    </div>
                <?php endif; ?>

            <?php elseif ($action === 'add' || $action === 'edit'): ?>
                <!-- 添加/编辑会员表单 -->
                <form method="post" action="?action=<?php echo $action; ?>" class="form-container">
                    <h3><?php echo $action === 'add' ? '添加会员' : '编辑会员'; ?></h3>

                    <?php if ($action === 'edit'): ?>
                        <input type="hidden" name="id" value="<?php echo $memberInfo['id']; ?>">
                    <?php endif; ?>

                    <div class="form-group">
                        <label for="name">会员姓名 *</label>
                        <input type="text" id="name" name="name" value="<?php echo $action === 'edit' ? htmlspecialchars($memberInfo['name']) : ''; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="phone">手机号码 *</label>
                        <input type="text" id="phone" name="phone" value="<?php echo $action === 'edit' ? htmlspecialchars($memberInfo['phone']) : ''; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="birthday">生日</label>
                        <input type="date" id="birthday" name="birthday" value="<?php echo $action === 'edit' && $memberInfo['birthday'] ? $memberInfo['birthday'] : ''; ?>">
                    </div>

                    <div class="form-group">
                        <label for="address">地址</label>
                        <input type="text" id="address" name="address" value="<?php echo $action === 'edit' ? htmlspecialchars($memberInfo['address'] ?? '') : ''; ?>">
                    </div>

                    <div class="form-group">
                        <label for="preference">购买偏好</label>
                        <input type="text" id="preference" name="preference" value="<?php echo $action === 'edit' ? htmlspecialchars($memberInfo['preference'] ?? '') : ''; ?>" placeholder="例如: 玫瑰花、多肉植物">
                    </div>

                    <div class="form-group">
                        <label for="level_id">会员等级</label>
                        <select id="level_id" name="level_id">
                            <?php foreach ($memberLevels as $level): ?>
                                <option value="<?php echo $level['id']; ?>" <?php echo ($action === 'edit' && $memberInfo['level_id'] == $level['id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($level['level_name']); ?> (<?php echo $level['discount'] * 10; ?>折)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <?php if ($action === 'edit'): ?>
                        <div class="form-group">
                            <label for="points">积分</label>
                            <input type="text" id="points" value="<?php echo $memberInfo['points']; ?>" readonly>
                            <small>积分不可直接修改，请使用积分管理功能调整</small>
                        </div>

                        <div class="form-group">
                            <label for="balance">储值余额</label>
                            <input type="text" id="balance" value="￥<?php echo number_format($memberInfo['balance'], 2); ?>" readonly>
                            <small>余额不可直接修改，请使用充值管理功能调整</small>
                        </div>
                    <?php endif; ?>

                    <div class="form-group">
                        <label for="status">状态</label>
                        <div class="checkbox-item">
                            <label>
                                <input type="checkbox" id="status" name="status" value="1" <?php echo $action === 'edit' && $memberInfo['status'] == 1 ? 'checked' : ($action === 'add' ? 'checked' : ''); ?>> 启用
                            </label>
                        </div>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary"><?php echo $action === 'add' ? '添加' : '保存'; ?></button>
                        <a href="?action=list" class="btn btn-secondary">取消</a>
                    </div>
                </form>

            <?php elseif ($action === 'view'): ?>
                <!-- 会员详情 -->
                <div class="form-container">
                    <h3>会员详情</h3>

                    <table class="info-table">
                        <tr>
                            <td width="20%">会员ID：</td>
                            <td><?php echo $memberInfo['id']; ?></td>
                        </tr>
                        <tr>
                            <td>会员姓名：</td>
                            <td><?php echo htmlspecialchars($memberInfo['name']); ?></td>
                        </tr>
                        <tr>
                            <td>手机号码：</td>
                            <td><?php echo htmlspecialchars($memberInfo['phone']); ?></td>
                        </tr>
                        <tr>
                            <td>生日：</td>
                            <td><?php echo $memberInfo['birthday'] ?: '未设置'; ?></td>
                        </tr>
                        <tr>
                            <td>地址：</td>
                            <td><?php echo htmlspecialchars($memberInfo['address'] ?? '未设置'); ?></td>
                        </tr>
                        <tr>
                            <td>购买偏好：</td>
                            <td><?php echo htmlspecialchars($memberInfo['preference'] ?? '未设置'); ?></td>
                        </tr>
                        <tr>
                            <td>会员等级：</td>
                            <td><?php echo htmlspecialchars($memberInfo['level_name']); ?></td>
                        </tr>
                        <tr>
                            <td>积分：</td>
                            <td><?php echo $memberInfo['points']; ?></td>
                        </tr>
                        <tr>
                            <td>储值余额：</td>
                            <td>￥<?php echo number_format($memberInfo['balance'], 2); ?></td>
                        </tr>
                        <tr>
                            <td>状态：</td>
                            <td><?php echo $memberInfo['status'] == 1 ? '<span class="status-active">启用</span>' : '<span class="status-inactive">禁用</span>'; ?></td>
                        </tr>
                        <tr>
                            <td>注册时间：</td>
                            <td><?php echo $memberInfo['create_time']; ?></td>
                        </tr>
                    </table>

                    <div class="form-actions">
                        <?php if (has_permission('member.edit')): ?>
                            <a href="?action=edit&id=<?php echo $memberInfo['id']; ?>" class="btn btn-primary">编辑</a>
                        <?php endif; ?>
                        <a href="?action=list" class="btn btn-secondary">返回</a>
                        <a href="points.php?search_member=<?php echo $memberInfo['id']; ?>" class="btn btn-success">积分记录</a>
                        <a href="recharge.php?search_member=<?php echo $memberInfo['id']; ?>" class="btn btn-success">充值记录</a>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>