<?php
// order/info.php - 订单详情页面
session_start();
require_once '../database_config.php';

// 检查权限
check_permission_or_die('order.view');

// 获取订单ID
$order_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($order_id <= 0) {
    die('无效的订单ID');
}

// 获取订单详情
$stmt = $pdo->prepare("
    SELECT o.*, m.name as member_name, m.phone as member_phone, s.name as store_name 
    FROM orders o 
    LEFT JOIN members m ON o.member_id = m.id
    LEFT JOIN stores s ON o.store_id = s.id
    WHERE o.id = ?
");
$stmt->execute([$order_id]);
$order = $stmt->fetch();

if (!$order) {
    die('订单不存在');
}

// 获取订单商品
$stmt = $pdo->prepare("SELECT * FROM order_items WHERE order_id = ? ORDER BY id");
$stmt->execute([$order_id]);
$order_items = $stmt->fetchAll();

// 获取订单支付记录
$stmt = $pdo->prepare("SELECT * FROM order_payments WHERE order_id = ? ORDER BY create_time DESC");
$stmt->execute([$order_id]);
$order_payments = $stmt->fetchAll();

// 获取订单退款记录
$stmt = $pdo->prepare("SELECT * FROM order_refunds WHERE order_id = ? ORDER BY create_time DESC");
$stmt->execute([$order_id]);
$order_refunds = $stmt->fetchAll();

// 记录访问日志
record_log("查看订单详情 ID:{$order_id}");

// 获取订单状态文本
function get_status_text($status)
{
    $status_array = [
        1 => '待付款',
        2 => '已付款',
        3 => '待配送',
        4 => '已完成',
        5 => '已取消',
        6 => '退款中',
        7 => '已退款'
    ];
    return isset($status_array[$status]) ? $status_array[$status] : '未知状态';
}

// 获取订单状态CSS类
function get_status_class($status)
{
    $class_array = [
        1 => 'text-warning',    // 待付款
        2 => 'text-primary',    // 已付款
        3 => 'text-info',       // 待配送
        4 => 'status-active',   // 已完成
        5 => 'status-inactive', // 已取消
        6 => 'text-warning',    // 退款中
        7 => 'status-inactive'  // 已退款
    ];
    return isset($class_array[$status]) ? $class_array[$status] : '';
}

// 获取支付方式文本
function get_payment_type_text($type)
{
    $types = [
        1 => '现金',
        2 => '微信',
        3 => '支付宝',
        4 => '信用卡',
        5 => '储值余额',
        6 => '积分抵扣'
    ];
    return isset($types[$type]) ? $types[$type] : '未知方式';
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>订单详情 - <?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单详情</h2>
            <div class="breadcrumb">
                <a href="index.php">订单管理</a> &gt; <a href="list.php">订单列表</a> &gt; 订单详情
            </div>
        </div>

        <div class="content">
            <!-- 订单详情 -->
            <div class="form-container">
                <h3>基本信息</h3>

                <table class="info-table">
                    <tr>
                        <td width="20%">订单编号：</td>
                        <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                    </tr>
                    <tr>
                        <td>订单状态：</td>
                        <td><span class="<?php echo get_status_class($order['status']); ?>"><?php echo get_status_text($order['status']); ?></span></td>
                    </tr>
                    <tr>
                        <td>下单时间：</td>
                        <td><?php echo date('Y-m-d H:i:s', strtotime($order['create_time'])); ?></td>
                    </tr>
                    <tr>
                        <td>最后更新：</td>
                        <td><?php echo date('Y-m-d H:i:s', strtotime($order['update_time'])); ?></td>
                    </tr>
                    <tr>
                        <td>会员信息：</td>
                        <td>
                            <?php if ($order['member_id']): ?>
                                <?php echo htmlspecialchars($order['member_name'] . ' (' . $order['member_phone'] . ')'); ?>
                            <?php else: ?>
                                非会员
                            <?php endif; ?>
                        </td>
                    </tr>
                    <tr>
                        <td>门店：</td>
                        <td><?php echo htmlspecialchars($order['store_name']); ?></td>
                    </tr>
                    <tr>
                        <td>操作员：</td>
                        <td><?php echo htmlspecialchars($order['operator']); ?></td>
                    </tr>
                </table>

                <h3>金额信息</h3>

                <table class="info-table">
                    <tr>
                        <td width="20%">订单总额：</td>
                        <td>￥<?php echo number_format($order['total_amount'], 2); ?></td>
                    </tr>
                    <tr>
                        <td>折扣金额：</td>
                        <td>￥<?php echo number_format($order['discount_amount'], 2); ?></td>
                    </tr>
                    <tr>
                        <td>实付金额：</td>
                        <td><span class="text-primary">￥<?php echo number_format($order['actual_amount'], 2); ?></span></td>
                    </tr>
                </table>

                <?php if (!empty($order['remark'])): ?>
                    <h3>订单备注</h3>

                    <table class="info-table">
                        <tr>
                            <td width="20%">备注：</td>
                            <td><?php echo nl2br(htmlspecialchars($order['remark'])); ?></td>
                        </tr>
                    </table>
                <?php endif; ?>

                <h3>订单商品</h3>

                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>商品名称</th>
                                <th>商品编码</th>
                                <th>单价</th>
                                <th>数量</th>
                                <th>小计</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($order_items)): ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无商品数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($order_items as $item): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($item['product_name']); ?></td>
                                        <td><?php echo htmlspecialchars($item['product_code']); ?></td>
                                        <td>￥<?php echo number_format($item['price'], 2); ?></td>
                                        <td><?php echo $item['quantity']; ?></td>
                                        <td>￥<?php echo number_format($item['subtotal'], 2); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <?php if (!empty($order_payments)): ?>
                    <h3>支付记录</h3>

                    <div class="table-container">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>支付方式</th>
                                    <th>支付金额</th>
                                    <th>支付时间</th>
                                    <th>操作员</th>
                                    <th>备注</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($order_payments as $payment): ?>
                                    <tr>
                                        <td><?php echo get_payment_type_text($payment['payment_type']); ?></td>
                                        <td>￥<?php echo number_format($payment['amount'], 2); ?></td>
                                        <td><?php echo date('Y-m-d H:i:s', strtotime($payment['create_time'])); ?></td>
                                        <td><?php echo htmlspecialchars($payment['operator']); ?></td>
                                        <td><?php echo htmlspecialchars($payment['remark']); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>

                <?php if (!empty($order_refunds)): ?>
                    <h3>退款记录</h3>

                    <div class="table-container">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>退款金额</th>
                                    <th>退款状态</th>
                                    <th>退款时间</th>
                                    <th>操作员</th>
                                    <th>原因</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($order_refunds as $refund): ?>
                                    <tr>
                                        <td>￥<?php echo number_format($refund['amount'], 2); ?></td>
                                        <td>
                                            <?php if ($refund['status'] == 1): ?>
                                                <span class="text-warning">处理中</span>
                                            <?php elseif ($refund['status'] == 2): ?>
                                                <span class="status-active">已完成</span>
                                            <?php else: ?>
                                                <span class="status-inactive">已拒绝</span>
                                            <?php endif; ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i:s', strtotime($refund['create_time'])); ?></td>
                                        <td><?php echo htmlspecialchars($refund['operator']); ?></td>
                                        <td><?php echo htmlspecialchars($refund['reason']); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>

                <div class="form-actions">
                    <a href="list.php" class="btn btn-secondary">返回列表</a>
                    <?php if (has_permission('order.edit')): ?>
                        <?php if ($order['status'] == 1): // 只有待付款状态才显示处理付款按钮 
                        ?>
                            <a href="payment.php?order_id=<?php echo $order_id; ?>" class="btn btn-primary">处理付款</a>
                        <?php endif; ?>
                        <?php if (!in_array($order['status'], [4, 5, 6, 7])): // 非终态才显示更新状态按钮 
                        ?>
                            <a href="status.php?order_id=<?php echo $order_id; ?>" class="btn btn-primary">更新状态</a>
                        <?php endif; ?>
                        <?php if (in_array($order['status'], [2, 3, 4]) && !in_array($order['status'], [6, 7])): // 已付款且非退款状态才显示申请退款按钮 
                        ?>
                            <a href="refund.php?order_id=<?php echo $order_id; ?>" class="btn btn-primary">申请退款</a>
                        <?php endif; ?>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</body>

</html>