<?php
// order/payment.php - 订单支付管理
session_start();
require_once '../database_config.php';

// 检查权限
check_permission_or_die('order.view');

// 处理操作
$action = isset($_GET['action']) ? $_GET['action'] : (isset($_POST['action']) ? $_POST['action'] : 'list');
$id = isset($_GET['id']) ? intval($_GET['id']) : (isset($_POST['id']) ? intval($_POST['id']) : 0);
$alert = '';

// 处理订单支付
if ($action == 'process_payment' && $id > 0 && has_permission('order.edit')) {
    $payment_type = isset($_POST['payment_type']) ? intval($_POST['payment_type']) : 0;
    $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
    $transaction_id = isset($_POST['transaction_id']) ? trim($_POST['transaction_id']) : '';

    try {
        $pdo->beginTransaction();

        // 检查订单状态
        $stmt = $pdo->prepare("SELECT * FROM orders WHERE id = ?");
        $stmt->execute([$id]);
        $order = $stmt->fetch();

        if (!$order) {
            throw new Exception("订单不存在");
        }

        if ($order['status'] != 1) {
            throw new Exception("只能为待付款的订单进行支付操作");
        }

        // 检查支付金额
        if ($amount != $order['actual_amount']) {
            throw new Exception("支付金额与订单金额不符");
        }

        // 添加支付记录
        $stmt = $pdo->prepare("
            INSERT INTO order_payments (order_id, payment_type, amount, transaction_id, status) 
            VALUES (?, ?, ?, ?, 2)
        ");
        $stmt->execute([$id, $payment_type, $amount, $transaction_id]);

        // 更新订单状态为已付款
        $stmt = $pdo->prepare("
            UPDATE orders SET status = 2, update_time = NOW() WHERE id = ?
        ");
        $stmt->execute([$id]);

        // 如果是会员储值支付，需要扣除会员余额
        if ($payment_type == 5 && $order['member_id']) {
            $stmt = $pdo->prepare("
                UPDATE members SET balance = balance - ? WHERE id = ?
            ");
            $stmt->execute([$amount, $order['member_id']]);

            // 记录会员余额变动
            record_log("会员ID:" . $order['member_id'] . " 使用储值支付订单:" . $order['order_no'] . " 金额:" . $amount);
        }

        $pdo->commit();

        // 记录日志
        record_log("处理订单支付 ID:{$id} 金额:{$amount} 支付方式:{$payment_type}");
        $alert = '<div class="alert alert-success">订单支付成功！</div>';

        // 重定向到订单详情页
        header("Location: list.php?action=view&id={$id}");
        exit;
    } catch (Exception $e) {
        $pdo->rollBack();
        $alert = '<div class="alert alert-danger">订单支付失败：' . $e->getMessage() . '</div>';
    }
}

// 获取待支付订单
if ($action == 'list') {
    $sql = "SELECT o.*, m.name as member_name 
            FROM orders o 
            LEFT JOIN members m ON o.member_id = m.id 
            WHERE o.status = 1 
            ORDER BY o.create_time DESC";
    $stmt = $pdo->query($sql);
    $pending_orders = $stmt->fetchAll();
}

// 获取订单详情
if (($action == 'pay' || $action == 'process_payment') && $id > 0) {
    $stmt = $pdo->prepare("
        SELECT o.*, m.name as member_name, m.balance, m.points 
        FROM orders o 
        LEFT JOIN members m ON o.member_id = m.id 
        WHERE o.id = ?
    ");
    $stmt->execute([$id]);
    $order = $stmt->fetch();

    if (!$order) {
        $alert = '<div class="alert alert-danger">订单不存在</div>';
        $action = 'list';
    } else if ($order['status'] != 1) {
        $alert = '<div class="alert alert-danger">只能为待付款的订单进行支付操作</div>';
        $action = 'list';
    } else {
        // 获取订单商品
        $stmt = $pdo->prepare("SELECT * FROM order_items WHERE order_id = ?");
        $stmt->execute([$id]);
        $items = $stmt->fetchAll();
    }
}

// 获取支付方式文本
function get_payment_type_text($type)
{
    $types = [
        1 => '现金',
        2 => '微信',
        3 => '支付宝',
        4 => '信用卡',
        5 => '储值余额',
        6 => '积分抵扣'
    ];
    return isset($types[$type]) ? $types[$type] : '未知方式';
}

// 获取订单状态文本
function get_status_text($status)
{
    $status_array = [
        1 => '待付款',
        2 => '已付款',
        3 => '待配送',
        4 => '已完成',
        5 => '已取消',
        6 => '退款中',
        7 => '已退款'
    ];
    return isset($status_array[$status]) ? $status_array[$status] : '未知状态';
}

// 在process_payment操作成功后添加重定向
if ($action == 'process_payment' && isset($success) && $success) {
    // 记录日志
    record_log("订单支付成功 订单ID:{$id} 金额:{$amount}");
    
    // 设置成功提示并返回列表
    $alert = '<div class="alert alert-success">订单支付成功</div>';
    $action = 'list';
    
    // 获取最新的待支付订单列表
    $sql = "SELECT o.*, m.name as member_name 
            FROM orders o 
            LEFT JOIN members m ON o.member_id = m.id 
            WHERE o.status = 1 
            ORDER BY o.create_time DESC";
    $stmt = $pdo->query($sql);
    $pending_orders = $stmt->fetchAll();
}

?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>订单支付 - <?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单支付</h2>
            <div class="breadcrumb">
                <a href="list.php">订单列表</a> &gt; 订单支付
            </div>
        </div>

        <div class="content">
            <?php echo $alert; ?>

            <?php if ($action == 'list'): ?>
                <!-- 待支付订单列表 -->

                <h3>待支付订单</h3>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>订单编号</th>
                                <th>会员</th>
                                <th>订单金额</th>
                                <th>实付金额</th>
                                <th>下单时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($pending_orders) > 0): ?>
                                <?php foreach ($pending_orders as $order): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                        <td><?php echo empty($order['member_name']) ? '非会员' : htmlspecialchars($order['member_name']); ?></td>
                                        <td>￥<?php echo number_format($order['total_amount'], 2); ?></td>
                                        <td>￥<?php echo number_format($order['actual_amount'], 2); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($order['create_time'])); ?></td>
                                        <td>
                                            <a href="payment.php?action=pay&id=<?php echo $order['id']; ?>" class="btn btn-sm btn-primary">支付</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无待支付订单</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php elseif ($action == 'pay' && isset($order)): ?>
                <!-- 支付订单表单 -->
                <div class="action-bar">
                    <a href="payment.php" class="btn btn-secondary">返回支付列表</a>
                </div>

                <h3>订单支付</h3>

                <!-- 订单信息 -->
                <div class="form-container">
                    <h4>订单信息</h4>
                    <table class="data-table">
                        <tr>
                            <th width="15%">订单编号</th>
                            <td width="35%"><?php echo htmlspecialchars($order['order_no']); ?></td>
                            <th width="15%">订单状态</th>
                            <td width="35%"><?php echo get_status_text($order['status']); ?></td>
                        </tr>
                        <tr>
                            <th>会员</th>
                            <td><?php echo empty($order['member_name']) ? '非会员' : htmlspecialchars($order['member_name']); ?></td>
                            <th>下单时间</th>
                            <td><?php echo date('Y-m-d H:i:s', strtotime($order['create_time'])); ?></td>
                        </tr>
                        <tr>
                            <th>订单金额</th>
                            <td>￥<?php echo number_format($order['total_amount'], 2); ?></td>
                            <th>折扣金额</th>
                            <td>￥<?php echo number_format($order['discount_amount'], 2); ?></td>
                        </tr>
                        <tr>
                            <th>使用积分</th>
                            <td><?php echo number_format($order['points_used']); ?> 积分</td>
                            <th>积分抵扣</th>
                            <td>￥<?php echo number_format($order['points_discount'], 2); ?></td>
                        </tr>
                        <tr>
                            <th>实付金额</th>
                            <td colspan="3">￥<?php echo number_format($order['actual_amount'], 2); ?></td>
                        </tr>
                    </table>
                </div>

                <!-- 商品信息 -->
                <div class="form-container">
                    <h4>商品信息</h4>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>商品编码</th>
                                <th>商品名称</th>
                                <th>单价</th>
                                <th>数量</th>
                                <th>小计</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($items as $item): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($item['product_code']); ?></td>
                                    <td><?php echo htmlspecialchars($item['product_name']); ?></td>
                                    <td>￥<?php echo number_format($item['price'], 2); ?></td>
                                    <td><?php echo $item['quantity']; ?></td>
                                    <td>￥<?php echo number_format($item['subtotal'], 2); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 支付表单 -->
                <div class="form-container">
                    <h4>支付方式</h4>
                    <form method="post" action="payment.php" onsubmit="return validateForm()">
                        <input type="hidden" name="action" value="process_payment">
                        <input type="hidden" name="id" value="<?php echo $order['id']; ?>">
                        <input type="hidden" name="amount" value="<?php echo $order['actual_amount']; ?>">

                        <div class="form-group">
                            <label for="payment_type">支付方式</label>
                            <select id="payment_type" name="payment_type" class="form-control" required onchange="handlePaymentTypeChange()">
                                <option value="">-- 请选择支付方式 --</option>
                                <option value="1">现金支付</option>
                                <option value="2">微信支付</option>
                                <option value="3">支付宝支付</option>
                                <option value="4">信用卡支付</option>
                                <?php if (!empty($order['member_name']) && $order['balance'] >= $order['actual_amount']): ?>
                                    <option value="5">会员余额支付（余额：￥<?php echo number_format($order['balance'], 2); ?>）</option>
                                <?php endif; ?>
                            </select>
                        </div>

                        <div class="form-group" id="transaction_id_group" style="display: none;">
                            <label for="transaction_id">交易流水号</label>
                            <input type="text" id="transaction_id" name="transaction_id" class="form-control">
                            <small>对于电子支付方式，请输入交易流水号</small>
                        </div>

                        <div class="form-group">
                            <label>应付金额</label>
                            <div class="form-control-static">￥<?php echo number_format($order['actual_amount'], 2); ?></div>
                        </div>

                        <!-- 会员支付信息 -->
                        <?php if (!empty($order['member_name']) && ($order['balance'] > 0 || $order['points'] > 0)): ?>
                        <div class="form-group">
                            <label>可用会员支付</label>
                            <div>
                                <?php if ($order['balance'] > 0): ?>
                                <div class="checkbox-item">
                                    <label>
                                        <input type="checkbox" name="use_balance" id="use_balance" value="1" <?php echo $order['balance'] >= $order['actual_amount'] ? '' : 'disabled'; ?>> 
                                        使用储值余额支付 (当前余额: ￥<?php echo number_format($order['balance'], 2); ?>)
                                    </label>
                                </div>
                                <?php endif; ?>
                                
                                <?php if ($order['points'] >= 100): ?>
                                <div class="checkbox-item">
                                    <label>
                                        <input type="checkbox" name="use_points" id="use_points" value="1"> 
                                        使用积分抵扣部分金额 (当前积分: <?php echo number_format($order['points']); ?>)
                                    </label>
                                    <small>100积分可抵扣￥1.00</small>
                                </div>
                                <?php endif; ?>
                            </div>
                        </div>
                        <?php endif; ?>
                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary">确认支付</button>
                            <a href="payment.php" class="btn btn-secondary">取消</a>
                        </div>

                    </form>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 根据支付方式显示/隐藏交易流水号输入框
        function handlePaymentTypeChange() {
            var paymentType = document.getElementById('payment_type').value;
            var transactionIdGroup = document.getElementById('transaction_id_group');

            // 对于电子支付方式（微信、支付宝、信用卡），显示交易流水号输入框
            if (paymentType == '2' || paymentType == '3' || paymentType == '4') {
                transactionIdGroup.style.display = 'block';
                document.getElementById('transaction_id').required = true;
            } else {
                transactionIdGroup.style.display = 'none';
                document.getElementById('transaction_id').required = false;
            }
        }

        // 表单验证
        function validateForm() {
            var paymentType = document.getElementById('payment_type').value;
            if (!paymentType) {
                alert('请选择支付方式');
                return false;
            }

            return true;
        }
    </script>
</body>

</html>