<?php
// order/refund.php - 订单退款管理
session_start();
require_once '../database_config.php';

// 检查权限
check_permission_or_die('order.view');

// 处理操作
$action = isset($_GET['action']) ? $_GET['action'] : (isset($_POST['action']) ? $_POST['action'] : 'list');
$id = isset($_GET['id']) ? intval($_GET['id']) : (isset($_POST['id']) ? intval($_POST['id']) : 0);
$order_id = isset($_GET['order_id']) ? intval($_GET['order_id']) : (isset($_POST['order_id']) ? intval($_POST['order_id']) : 0);
$alert = '';

// 提交退款申请
if ($action == 'apply' && has_permission('order.edit')) {
    $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
    $refund_amount = isset($_POST['refund_amount']) ? floatval($_POST['refund_amount']) : 0;
    $reason = isset($_POST['reason']) ? trim($_POST['reason']) : '';

    try {
        // 检查订单是否存在
        $stmt = $pdo->prepare("SELECT * FROM orders WHERE id = ?");
        $stmt->execute([$order_id]);
        $order = $stmt->fetch();

        if (!$order) {
            throw new Exception("订单不存在");
        }

        // 检查订单状态
        if (!in_array($order['status'], [2, 3])) {
            throw new Exception("只有已付款或待配送的订单可以申请退款");
        }

        // 检查退款金额
        if ($refund_amount <= 0 || $refund_amount > $order['actual_amount']) {
            throw new Exception("退款金额无效");
        }

        // 生成退款单号
        $refund_no = 'REF' . date('YmdHis') . rand(1000, 9999);

        // 开始事务
        $pdo->beginTransaction();

        // 创建退款记录
        $stmt = $pdo->prepare("
            INSERT INTO order_refunds (order_id, refund_no, refund_amount, reason, status, apply_time) 
            VALUES (?, ?, ?, ?, 1, NOW())
        ");
        $stmt->execute([$order_id, $refund_no, $refund_amount, $reason]);

        // 更新订单状态为退款中
        $stmt = $pdo->prepare("UPDATE orders SET status = 6, update_time = NOW() WHERE id = ?");
        $stmt->execute([$order_id]);

        // 提交事务
        $pdo->commit();

        // 记录日志
        record_log("创建退款申请 订单ID:{$order_id} 金额:{$refund_amount}");
        $alert = '<div class="alert alert-success">退款申请已提交，等待审核</div>';

        // 返回列表
        $action = 'list';
    } catch (Exception $e) {
        // 回滚事务
        $pdo->rollBack();
        $alert = '<div class="alert alert-danger">提交退款申请失败：' . $e->getMessage() . '</div>';
    }
}

// 审核退款
if ($action == 'review' && $id > 0 && has_permission('order.edit')) {
    $status = isset($_POST['status']) ? intval($_POST['status']) : 0;
    $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

    try {
        // 检查退款记录
        $stmt = $pdo->prepare("SELECT r.*, o.member_id, o.actual_amount, o.order_no FROM order_refunds r LEFT JOIN orders o ON r.order_id = o.id WHERE r.id = ?");
        $stmt->execute([$id]);
        $refund = $stmt->fetch();

        if (!$refund) {
            throw new Exception("退款记录不存在");
        }

        if ($refund['status'] != 1) {
            throw new Exception("只能审核申请中的退款");
        }

        // 开始事务
        $pdo->beginTransaction();

        // 更新退款状态
        $stmt = $pdo->prepare("
            UPDATE order_refunds 
            SET status = ?, remark = ?, audit_user = ?, audit_time = NOW() 
            WHERE id = ?
        ");
        $stmt->execute([$status, $remark, $_SESSION['username'], $id]);

        // 更新订单状态
        if ($status == 3) { // 退款成功
            // 更新订单状态为已退款
            $stmt = $pdo->prepare("UPDATE orders SET status = 7, update_time = NOW() WHERE id = ?");
            $stmt->execute([$refund['order_id']]);

            // 如果是会员，退款到会员余额
            if ($refund['member_id']) {
                $stmt = $pdo->prepare("UPDATE members SET balance = balance + ? WHERE id = ?");
                $stmt->execute([$refund['refund_amount'], $refund['member_id']]);

                // 记录会员余额变动
                record_log("会员ID:{$refund['member_id']} 订单退款入账 订单号:{$refund['order_no']} 金额:{$refund['refund_amount']}");
            }
        } else if ($status == 4) { // 退款失败
            // 恢复订单状态为原状态（已付款）
            $stmt = $pdo->prepare("UPDATE orders SET status = 2, update_time = NOW() WHERE id = ?");
            $stmt->execute([$refund['order_id']]);
        }

        // 提交事务
        $pdo->commit();

        // 记录日志
        $status_text = $status == 3 ? '通过' : '拒绝';
        record_log("审核退款申请 ID:{$id} 结果:{$status_text}");
        $alert = '<div class="alert alert-success">退款审核已完成</div>';

        // 返回列表
        $action = 'list';
    } catch (Exception $e) {
        // 回滚事务
        $pdo->rollBack();
        $alert = '<div class="alert alert-danger">审核退款失败：' . $e->getMessage() . '</div>';
    }
}

// 获取退款申请表单
if ($action == 'apply_form' && $order_id > 0) {
    $stmt = $pdo->prepare("
        SELECT o.*, m.name as member_name 
        FROM orders o 
        LEFT JOIN members m ON o.member_id = m.id 
        WHERE o.id = ?
    ");
    $stmt->execute([$order_id]);
    $order = $stmt->fetch();

    if (!$order) {
        $alert = '<div class="alert alert-danger">订单不存在</div>';
        $action = 'list';
    } else if (!in_array($order['status'], [2, 3])) {
        $alert = '<div class="alert alert-danger">只有已付款或待配送的订单可以申请退款</div>';
        $action = 'list';
    }
}

// 获取退款详情
if ($action == 'view' && $id > 0) {
    $stmt = $pdo->prepare("
        SELECT r.*, o.order_no, o.actual_amount, m.name as member_name 
        FROM order_refunds r 
        LEFT JOIN orders o ON r.order_id = o.id 
        LEFT JOIN members m ON o.member_id = m.id 
        WHERE r.id = ?
    ");
    $stmt->execute([$id]);
    $refund = $stmt->fetch();

    if (!$refund) {
        $alert = '<div class="alert alert-danger">退款记录不存在</div>';
        $action = 'list';
    }
}

// 获取退款列表
$status_filter = isset($_GET['status']) ? intval($_GET['status']) : 0;
$order_no = isset($_GET['order_no']) ? trim($_GET['order_no']) : '';
$refund_no = isset($_GET['refund_no']) ? trim($_GET['refund_no']) : '';
$start_date = isset($_GET['start_date']) ? trim($_GET['start_date']) : '';
$end_date = isset($_GET['end_date']) ? trim($_GET['end_date']) : '';

// 构建查询条件
$where_conditions = [];
$params = [];

if ($status_filter > 0) {
    $where_conditions[] = "r.status = ?";
    $params[] = $status_filter;
}

if (!empty($order_no)) {
    $where_conditions[] = "o.order_no LIKE ?";
    $params[] = "%{$order_no}%";
}

if (!empty($refund_no)) {
    $where_conditions[] = "r.refund_no LIKE ?";
    $params[] = "%{$refund_no}%";
}

if (!empty($start_date)) {
    $where_conditions[] = "DATE(r.apply_time) >= ?";
    $params[] = $start_date;
}

if (!empty($end_date)) {
    $where_conditions[] = "DATE(r.apply_time) <= ?";
    $params[] = $end_date;
}

$where_clause = !empty($where_conditions) ? " WHERE " . implode(" AND ", $where_conditions) : "";

// 分页设置
$items_per_page = 10;
$current_page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$current_page = max(1, $current_page);

// 计算偏移量
$offset = ($current_page - 1) * $items_per_page;

// 获取退款数据
$sql = "
    SELECT r.*, o.order_no, o.actual_amount, m.name as member_name 
    FROM order_refunds r 
    LEFT JOIN orders o ON r.order_id = o.id 
    LEFT JOIN members m ON o.member_id = m.id
" . $where_clause . " 
    ORDER BY r.apply_time DESC LIMIT " . $offset . ", " . $items_per_page;

$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$refunds = $stmt->fetchAll();

// 获取退款状态文本
function get_refund_status_text($status)
{
    $statuses = [
        1 => '申请中',
        2 => '已审核',
        3 => '退款成功',
        4 => '退款失败'
    ];
    return isset($statuses[$status]) ? $statuses[$status] : '未知状态';
}

// 获取退款状态CSS类
function get_refund_status_class($status)
{
    $classes = [
        1 => 'text-warning',    // 申请中
        2 => 'text-primary',    // 已审核
        3 => 'status-active',   // 退款成功
        4 => 'status-inactive'  // 退款失败
    ];
    return isset($classes[$status]) ? $classes[$status] : '';
}

// 添加操作成功后的处理逻辑
// 在apply和review操作成功后添加
if ($action == 'apply' || $action == 'review') {
    if ($success) {
        // 由于已经设置了action = 'list'，直接在视图中显示成功提示即可
        $alert = '<div class="alert alert-success">操作成功</div>';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>退款管理 - <?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>退款管理</h2>
            <div class="breadcrumb">
                <a href="index.php">订单管理</a> / 退款管理
            </div>
        </div>

        <div class="content">
            <?php echo $alert; ?>

            <?php if ($action == 'list'): ?>
                <!-- 搜索表单 -->
                <div class="filter-form">
                    <form method="get" action="refund.php">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="order_no">订单编号</label>
                                <input type="text" id="order_no" name="order_no" value="<?php echo htmlspecialchars($order_no); ?>">
                            </div>
                            <div class="filter-item">
                                <label for="refund_no">退款单号</label>
                                <input type="text" id="refund_no" name="refund_no" value="<?php echo htmlspecialchars($refund_no); ?>">
                            </div>
                            <div class="filter-item">
                                <label for="status">退款状态</label>
                                <select id="status" name="status">
                                    <option value="0">全部状态</option>
                                    <option value="1" <?php echo $status_filter == 1 ? 'selected' : ''; ?>>申请中</option>
                                    <option value="2" <?php echo $status_filter == 2 ? 'selected' : ''; ?>>已审核</option>
                                    <option value="3" <?php echo $status_filter == 3 ? 'selected' : ''; ?>>退款成功</option>
                                    <option value="4" <?php echo $status_filter == 4 ? 'selected' : ''; ?>>退款失败</option>
                                </select>
                            </div>
                        </div>
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="start_date">开始日期</label>
                                <input type="date" id="start_date" name="start_date" value="<?php echo htmlspecialchars($start_date); ?>">
                            </div>
                            <div class="filter-item">
                                <label for="end_date">结束日期</label>
                                <input type="date" id="end_date" name="end_date" value="<?php echo htmlspecialchars($end_date); ?>">
                            </div>
                            <div class="filter-item" style="align-self: flex-end;">
                                <button type="submit" class="btn btn-primary">搜索</button>
                                <a href="refund.php" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>                

                <!-- 退款列表 -->
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>退款单号</th>
                                <th>订单编号</th>
                                <th>会员</th>
                                <th>退款金额</th>
                                <th>申请原因</th>
                                <th>申请时间</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($refunds) > 0): ?>
                                <?php foreach ($refunds as $refund): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($refund['refund_no']); ?></td>
                                        <td><?php echo htmlspecialchars($refund['order_no']); ?></td>
                                        <td><?php echo empty($refund['member_name']) ? '非会员' : htmlspecialchars($refund['member_name']); ?></td>
                                        <td>￥<?php echo number_format($refund['refund_amount'], 2); ?></td>
                                        <td><?php echo htmlspecialchars($refund['reason']); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($refund['apply_time'])); ?></td>
                                        <td class="<?php echo get_refund_status_class($refund['status']); ?>">
                                            <?php echo get_refund_status_text($refund['status']); ?>
                                        </td>
                                        <td>
                                            <a href="refund.php?action=view&id=<?php echo $refund['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                            <?php if ($refund['status'] == 1 && has_permission('order.edit')): ?>
                                                <a href="refund.php?action=review_form&id=<?php echo $refund['id']; ?>" class="btn btn-sm btn-primary">审核</a>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无退款数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 分页 -->
                <?php if ($total_pages > 1): ?>
                    <div class="pagination">
                        <?php if ($current_page > 1): ?>
                            <a href="refund.php?page=1<?php echo !empty($order_no) ? '&order_no=' . urlencode($order_no) : ''; ?><?php echo !empty($refund_no) ? '&refund_no=' . urlencode($refund_no) : ''; ?><?php echo $status_filter > 0 ? '&status=' . $status_filter : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link">首页</a>
                            <a href="refund.php?page=<?php echo $current_page - 1; ?><?php echo !empty($order_no) ? '&order_no=' . urlencode($order_no) : ''; ?><?php echo !empty($refund_no) ? '&refund_no=' . urlencode($refund_no) : ''; ?><?php echo $status_filter > 0 ? '&status=' . $status_filter : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link">上一页</a>
                        <?php endif; ?>

                        <?php
                        // 显示当前页码附近的页码
                        $start_page = max(1, $current_page - 2);
                        $end_page = min($total_pages, $current_page + 2);

                        for ($i = $start_page; $i <= $end_page; $i++):
                        ?>
                            <a href="refund.php?page=<?php echo $i; ?><?php echo !empty($order_no) ? '&order_no=' . urlencode($order_no) : ''; ?><?php echo !empty($refund_no) ? '&refund_no=' . urlencode($refund_no) : ''; ?><?php echo $status_filter > 0 ? '&status=' . $status_filter : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link <?php echo $i == $current_page ? 'current' : ''; ?>"><?php echo $i; ?></a>
                        <?php endfor; ?>

                        <?php if ($current_page < $total_pages): ?>
                            <a href="refund.php?page=<?php echo $current_page + 1; ?><?php echo !empty($order_no) ? '&order_no=' . urlencode($order_no) : ''; ?><?php echo !empty($refund_no) ? '&refund_no=' . urlencode($refund_no) : ''; ?><?php echo $status_filter > 0 ? '&status=' . $status_filter : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link">下一页</a>
                            <a href="refund.php?page=<?php echo $total_pages; ?><?php echo !empty($order_no) ? '&order_no=' . urlencode($order_no) : ''; ?><?php echo !empty($refund_no) ? '&refund_no=' . urlencode($refund_no) : ''; ?><?php echo $status_filter > 0 ? '&status=' . $status_filter : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link">末页</a>
                        <?php endif; ?>
                    </div>
                    <div class="pagination-info">
                        共 <?php echo $total_items; ?> 条记录，当前第 <?php echo $current_page; ?>/<?php echo $total_pages; ?> 页
                    </div>
                <?php endif; ?>

            <?php elseif ($action == 'apply_form' && isset($order)): ?>
                <!-- 退款申请表单 -->
                <div class="action-bar">
                    <a href="list.php" class="btn btn-secondary">返回订单列表</a>
                </div>

                <h3>申请退款</h3>

                <!-- 订单信息 -->
                <div class="form-container">
                    <h4>订单信息</h4>
                    <table class="data-table">
                        <tr>
                            <th width="15%">订单编号</th>
                            <td width="35%"><?php echo htmlspecialchars($order['order_no']); ?></td>
                            <th width="15%">会员</th>
                            <td width="35%"><?php echo empty($order['member_name']) ? '非会员' : htmlspecialchars($order['member_name']); ?></td>
                        </tr>
                        <tr>
                            <th>订单金额</th>
                            <td>￥<?php echo number_format($order['total_amount'], 2); ?></td>
                            <th>实付金额</th>
                            <td>￥<?php echo number_format($order['actual_amount'], 2); ?></td>
                        </tr>
                    </table>
                </div>

                <!-- 申请表单 -->
                <div class="form-container">
                    <form method="post" action="refund.php">
                        <input type="hidden" name="action" value="apply">
                        <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">

                        <div class="form-group">
                            <label for="refund_amount">退款金额</label>
                            <input type="number" id="refund_amount" name="refund_amount" step="0.01" min="0.01" max="<?php echo $order['actual_amount']; ?>" value="<?php echo $order['actual_amount']; ?>" class="form-control" required>
                            <small>最大可退款金额：￥<?php echo number_format($order['actual_amount'], 2); ?></small>
                        </div>

                        <div class="form-group">
                            <label for="reason">退款原因</label>
                            <textarea id="reason" name="reason" class="form-control" rows="3" required></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary">提交申请</button>
                            <a href="list.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>

            <?php elseif ($action == 'view' && isset($refund)): ?>
                <!-- 退款详情 -->
                <div class="action-bar">
                    <a href="refund.php" class="btn btn-secondary">返回退款列表</a>
                    <a href="list.php?action=view&id=<?php echo $refund['order_id']; ?>" class="btn btn-primary">查看订单详情</a>
                </div>

                <h3>退款详情</h3>

                <div class="form-container">
                    <table class="data-table">
                        <tr>
                            <th width="15%">退款单号</th>
                            <td width="35%"><?php echo htmlspecialchars($refund['refund_no']); ?></td>
                            <th width="15%">订单编号</th>
                            <td width="35%"><?php echo htmlspecialchars($refund['order_no']); ?></td>
                        </tr>
                        <tr>
                            <th>会员</th>
                            <td><?php echo empty($refund['member_name']) ? '非会员' : htmlspecialchars($refund['member_name']); ?></td>
                            <th>订单金额</th>
                            <td>￥<?php echo number_format($refund['actual_amount'], 2); ?></td>
                        </tr>
                        <tr>
                            <th>退款金额</th>
                            <td>￥<?php echo number_format($refund['refund_amount'], 2); ?></td>
                            <th>退款状态</th>
                            <td class="<?php echo get_refund_status_class($refund['status']); ?>">
                                <?php echo get_refund_status_text($refund['status']); ?>
                            </td>
                        </tr>
                        <tr>
                            <th>申请原因</th>
                            <td><?php echo htmlspecialchars($refund['reason']); ?></td>
                            <th>申请时间</th>
                            <td><?php echo date('Y-m-d H:i:s', strtotime($refund['apply_time'])); ?></td>
                        </tr>
                        <?php if ($refund['status'] >= 2): ?>
                            <tr>
                                <th>审核人</th>
                                <td><?php echo htmlspecialchars($refund['audit_user']); ?></td>
                                <th>审核时间</th>
                                <td><?php echo date('Y-m-d H:i:s', strtotime($refund['audit_time'])); ?></td>
                            </tr>
                            <tr>
                                <th>审核备注</th>
                                <td colspan="3"><?php echo htmlspecialchars($refund['remark'] ?: '无'); ?></td>
                            </tr>
                        <?php endif; ?>
                    </table>
                </div>

                <?php if ($refund['status'] == 1 && has_permission('order.edit')): ?>
                    <div class="action-bar">
                        <a href="refund.php?action=review_form&id=<?php echo $refund['id']; ?>" class="btn btn-primary">审核退款</a>
                    </div>
                <?php endif; ?>

            <?php elseif ($action == 'review_form' && $id > 0 && has_permission('order.edit')): ?>
                <!-- 退款审核表单 -->
                <?php
                // 获取退款申请信息
                $stmt = $pdo->prepare("
                    SELECT r.*, o.order_no, o.actual_amount, m.name as member_name 
                    FROM order_refunds r 
                    LEFT JOIN orders o ON r.order_id = o.id 
                    LEFT JOIN members m ON o.member_id = m.id 
                    WHERE r.id = ?
                ");
                $stmt->execute([$id]);
                $refund = $stmt->fetch();

                if (!$refund) {
                    echo '<div class="alert alert-danger">退款记录不存在</div>';
                    echo '<div class="action-bar"><a href="refund.php" class="btn btn-secondary">返回退款列表</a></div>';
                } elseif ($refund['status'] != 1) {
                    echo '<div class="alert alert-danger">只能审核申请中的退款</div>';
                    echo '<div class="action-bar"><a href="refund.php" class="btn btn-secondary">返回退款列表</a></div>';
                } else {
                ?>
                    <div class="action-bar">
                        <a href="refund.php" class="btn btn-secondary">返回退款列表</a>
                    </div>

                    <h3>审核退款申请</h3>

                    <!-- 退款申请信息 -->
                    <div class="form-container">
                        <h4>退款申请信息</h4>
                        <table class="data-table">
                            <tr>
                                <th width="15%">退款单号</th>
                                <td width="35%"><?php echo htmlspecialchars($refund['refund_no']); ?></td>
                                <th width="15%">订单编号</th>
                                <td width="35%"><?php echo htmlspecialchars($refund['order_no']); ?></td>
                            </tr>
                            <tr>
                                <th>会员</th>
                                <td><?php echo empty($refund['member_name']) ? '非会员' : htmlspecialchars($refund['member_name']); ?></td>
                                <th>订单金额</th>
                                <td>￥<?php echo number_format($refund['actual_amount'], 2); ?></td>
                            </tr>
                            <tr>
                                <th>退款金额</th>
                                <td>￥<?php echo number_format($refund['refund_amount'], 2); ?></td>
                                <th>申请时间</th>
                                <td><?php echo date('Y-m-d H:i:s', strtotime($refund['apply_time'])); ?></td>
                            </tr>
                            <tr>
                                <th>申请原因</th>
                                <td colspan="3"><?php echo htmlspecialchars($refund['reason']); ?></td>
                            </tr>
                        </table>
                    </div>

                    <!-- 审核表单 -->
                    <div class="form-container">
                        <h4>审核结果</h4>
                        <form method="post" action="refund.php">
                            <input type="hidden" name="action" value="review">
                            <input type="hidden" name="id" value="<?php echo $refund['id']; ?>">

                            <div class="form-group">
                                <label>审核结果</label>
                                <div>
                                    <label class="radio-inline">
                                        <input type="radio" name="status" value="3" required> 同意退款
                                    </label>
                                    <label class="radio-inline" style="margin-left: 20px;">
                                        <input type="radio" name="status" value="4" required> 拒绝退款
                                    </label>
                                </div>
                            </div>

                            <div class="form-group">
                                <label for="remark">审核备注</label>
                                <textarea id="remark" name="remark" class="form-control" rows="3"></textarea>
                            </div>

                            <div class="form-actions">
                                <button type="submit" class="btn btn-primary">提交审核</button>
                                <a href="refund.php" class="btn btn-secondary">取消</a>
                            </div>
                        </form>
                    </div>
                <?php } ?>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>