<?php
// product/supplier.php - 供应商管理页面
session_start();
require_once '../database_config.php';

// 检查用户是否有访问权限
check_permission_or_die('product');

// 处理供应商添加/修改/删除操作
$message = '';
$message_type = '';

// 处理添加/修改供应商
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    if ($_POST['action'] == 'add' || $_POST['action'] == 'edit') {
        // 验证输入
        $required_fields = ['name', 'contact_person', 'phone'];
        $missing_fields = [];

        foreach ($required_fields as $field) {
            if (empty($_POST[$field])) {
                $missing_fields[] = $field;
            }
        }

        if (!empty($missing_fields)) {
            $message = '请填写所有必填字段: ' . implode(', ', $missing_fields);
            $message_type = 'danger';
        } else {
            // 准备数据
            $data = [
                'name' => $_POST['name'],
                'contact_person' => $_POST['contact_person'],
                'phone' => $_POST['phone'],
                'address' => $_POST['address'],
                'status' => isset($_POST['status']) ? 1 : 0
            ];

            try {
                // 添加或修改供应商
                if ($_POST['action'] == 'add') {
                    // 检查供应商是否已存在
                    $stmt = $pdo->prepare("SELECT id FROM suppliers WHERE name = ?");
                    $stmt->execute([$data['name']]);
                    if ($stmt->rowCount() > 0) {
                        $message = '供应商名称已存在，请使用其他名称';
                        $message_type = 'danger';
                    } else {
                        // 插入新供应商
                        $columns = implode(', ', array_keys($data));
                        $placeholders = implode(', ', array_fill(0, count($data), '?'));

                        $stmt = $pdo->prepare("INSERT INTO suppliers ($columns) VALUES ($placeholders)");
                        $stmt->execute(array_values($data));

                        $supplier_id = $pdo->lastInsertId();
                        $message = '供应商添加成功！';
                        $message_type = 'success';

                        // 记录操作日志
                        record_log("添加供应商: {$data['name']} (ID: $supplier_id)");
                    }
                } else { // 修改供应商
                    $supplier_id = $_POST['supplier_id'];

                    // 检查供应商名称是否与其他供应商重复
                    $stmt = $pdo->prepare("SELECT id FROM suppliers WHERE name = ? AND id != ?");
                    $stmt->execute([$data['name'], $supplier_id]);
                    if ($stmt->rowCount() > 0) {
                        $message = '供应商名称已被使用，请更换';
                        $message_type = 'danger';
                    } else {
                        // 更新供应商信息
                        $set_clauses = [];
                        foreach ($data as $key => $value) {
                            $set_clauses[] = "$key = ?";
                        }
                        $set_clause = implode(', ', $set_clauses);

                        $values = array_values($data);
                        $values[] = $supplier_id; // WHERE条件的值

                        $stmt = $pdo->prepare("UPDATE suppliers SET $set_clause WHERE id = ?");
                        $stmt->execute($values);

                        $message = '供应商信息更新成功！';
                        $message_type = 'success';

                        // 记录操作日志
                        record_log("更新供应商: {$data['name']} (ID: $supplier_id)");
                    }
                }
            } catch (PDOException $e) {
                $message = '操作失败: ' . $e->getMessage();
                $message_type = 'danger';
            }
        }
    } elseif ($_POST['action'] == 'status' && isset($_POST['supplier_id']) && isset($_POST['status'])) {
        $supplier_id = $_POST['supplier_id'];
        $status = $_POST['status'];

        try {
            // 更新供应商状态
            $stmt = $pdo->prepare("UPDATE suppliers SET status = ? WHERE id = ?");
            $stmt->execute([$status, $supplier_id]);

            // 获取供应商名称用于日志记录
            $stmt = $pdo->prepare("SELECT name FROM suppliers WHERE id = ?");
            $stmt->execute([$supplier_id]);
            $supplier_name = $stmt->fetch()['name'];

            $status_text = $status ? '启用' : '禁用';
            $message = "供应商已{$status_text}！";
            $message_type = 'success';

            // 记录操作日志
            record_log("修改供应商状态: $supplier_name (ID: $supplier_id) - {$status_text}");
        } catch (PDOException $e) {
            $message = '操作失败: ' . $e->getMessage();
            $message_type = 'danger';
        }
    }
}

// 准备查询条件
$where_conditions = [];
$params = [];

// 过滤条件
$filter_status = isset($_GET['status']) ? $_GET['status'] : '';
if ($filter_status !== '') {
    $where_conditions[] = "status = ?";
    $params[] = $filter_status;
}

$filter_keyword = isset($_GET['keyword']) ? $_GET['keyword'] : '';
if (!empty($filter_keyword)) {
    $where_conditions[] = "(name LIKE ? OR contact_person LIKE ? OR phone LIKE ? OR address LIKE ?)";
    $params[] = "%$filter_keyword%";
    $params[] = "%$filter_keyword%";
    $params[] = "%$filter_keyword%";
    $params[] = "%$filter_keyword%";
}

// 构建WHERE子句
$where_clause = !empty($where_conditions) ? "WHERE " . implode(" AND ", $where_conditions) : "";

// 分页
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$limit = 10;
$offset = ($page - 1) * $limit;

// 获取总记录数
$count_sql = "SELECT COUNT(*) as total FROM suppliers $where_clause";
$stmt = $pdo->prepare($count_sql);
$stmt->execute($params);
$total_records = $stmt->fetch()['total'];
$total_pages = ceil($total_records / $limit);

// 获取分页数据
$sql = "SELECT * FROM suppliers $where_clause ORDER BY id DESC LIMIT $offset, $limit";
$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$suppliers = $stmt->fetchAll();

// 获取每个供应商的采购记录数量
$supplier_purchase_counts = [];
foreach ($suppliers as $supplier) {
    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM inventory_records WHERE supplier_id = ? AND type = 1");
    $stmt->execute([$supplier['id']]);
    $supplier_purchase_counts[$supplier['id']] = $stmt->fetch()['count'];
}

// 记录操作日志
record_log("访问供应商管理页面");
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>供应商管理 - <?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>供应商管理</h2>
            <div class="breadcrumb">
                <a href="index.php">商品与库存管理</a> &gt;
                供应商管理
            </div>
        </div>

        <div class="content">
            <?php if (!empty($message)): ?>
                <div class="alert alert-<?php echo $message_type; ?>">
                    <?php echo $message; ?>
                </div>
            <?php endif; ?>

            <!-- 添加供应商按钮 -->
            <div class="action-bar">
                <button class="btn btn-primary" onclick="toggleForm('addSupplierForm')">添加新供应商</button>
            </div>

            <!-- 添加供应商表单 -->
            <div id="addSupplierForm" class="form-container" style="display: none;">
                <h3>添加新供应商</h3>
                <form method="post" action="supplier.php">
                    <input type="hidden" name="action" value="add">

                    <div class="form-group">
                        <label for="name">供应商名称 <span class="text-danger">*</span></label>
                        <input type="text" id="name" name="name" required>
                    </div>

                    <div class="form-group">
                        <label for="contact_person">联系人 <span class="text-danger">*</span></label>
                        <input type="text" id="contact_person" name="contact_person" required>
                    </div>

                    <div class="form-group">
                        <label for="phone">联系电话 <span class="text-danger">*</span></label>
                        <input type="text" id="phone" name="phone" required>
                    </div>

                    <div class="form-group">
                        <label for="address">地址</label>
                        <input type="text" id="address" name="address">
                    </div>

                    <div class="form-group">
                        <label for="status">
                            <input type="checkbox" id="status" name="status" checked>
                            状态（勾选为启用，不勾选为禁用）
                        </label>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="toggleForm('addSupplierForm')">取消</button>
                    </div>
                </form>
            </div>

            <!-- 编辑供应商表单 -->
            <div id="editSupplierForm" class="form-container" style="display: none;">
                <h3>编辑供应商</h3>
                <form method="post" action="supplier.php">
                    <input type="hidden" name="action" value="edit">
                    <input type="hidden" name="supplier_id" id="edit_supplier_id">

                    <div class="form-group">
                        <label for="edit_name">供应商名称 <span class="text-danger">*</span></label>
                        <input type="text" id="edit_name" name="name" required>
                    </div>

                    <div class="form-group">
                        <label for="edit_contact_person">联系人 <span class="text-danger">*</span></label>
                        <input type="text" id="edit_contact_person" name="contact_person" required>
                    </div>

                    <div class="form-group">
                        <label for="edit_phone">联系电话 <span class="text-danger">*</span></label>
                        <input type="text" id="edit_phone" name="phone" required>
                    </div>

                    <div class="form-group">
                        <label for="edit_address">地址</label>
                        <input type="text" id="edit_address" name="address">
                    </div>

                    <div class="form-group">
                        <label for="edit_status">
                            <input type="checkbox" id="edit_status" name="status">
                            状态（勾选为启用，不勾选为禁用）
                        </label>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="toggleForm('editSupplierForm')">取消</button>
                    </div>
                </form>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="supplier.php">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="status">供应商状态</label>
                            <select name="status" id="status">
                                <option value="">所有状态</option>
                                <option value="1" <?php echo $filter_status === '1' ? 'selected' : ''; ?>>启用</option>
                                <option value="0" <?php echo $filter_status === '0' ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="keyword">关键字搜索</label>
                            <input type="text" id="keyword" name="keyword" placeholder="供应商名称/联系人/电话/地址" value="<?php echo htmlspecialchars($filter_keyword); ?>">
                        </div>
                        <div class="filter-item">
                            <label>&nbsp;</label>
                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="supplier.php" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 供应商表格 -->
            <div class="table-responsive">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>供应商名称</th>
                            <th>联系人</th>
                            <th>联系电话</th>
                            <th>地址</th>
                            <th>采购记录</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($suppliers as $supplier): ?>
                            <tr>
                                <td><?php echo $supplier['id']; ?></td>
                                <td><?php echo htmlspecialchars($supplier['name']); ?></td>
                                <td><?php echo htmlspecialchars($supplier['contact_person']); ?></td>
                                <td><?php echo htmlspecialchars($supplier['phone']); ?></td>
                                <td><?php echo htmlspecialchars($supplier['address']); ?></td>
                                <td>
                                    <?php echo $supplier_purchase_counts[$supplier['id']]; ?>
                                    <?php if ($supplier_purchase_counts[$supplier['id']] > 0): ?>
                                        <a href="inventory.php?supplier_id=<?php echo $supplier['id']; ?>" class="btn btn-sm btn-primary">查看</a>
                                    <?php endif; ?>
                                </td>
                                <td class="<?php echo $supplier['status'] ? 'status-active' : 'status-inactive'; ?>">
                                    <?php echo $supplier['status'] ? '启用' : '禁用'; ?>
                                </td>
                                <td>
                                    <button class="btn btn-sm btn-primary" onclick="showEditForm(<?php echo htmlspecialchars(json_encode($supplier)); ?>)">编辑</button>

                                    <?php if ($supplier['status']): ?>
                                        <form method="post" action="supplier.php" style="display:inline;">
                                            <input type="hidden" name="action" value="status">
                                            <input type="hidden" name="supplier_id" value="<?php echo $supplier['id']; ?>">
                                            <input type="hidden" name="status" value="0">
                                            <button type="submit" class="btn btn-sm btn-secondary" onclick="return confirm('确定要禁用此供应商吗？')">禁用</button>
                                        </form>
                                    <?php else: ?>
                                        <form method="post" action="supplier.php" style="display:inline;">
                                            <input type="hidden" name="action" value="status">
                                            <input type="hidden" name="supplier_id" value="<?php echo $supplier['id']; ?>">
                                            <input type="hidden" name="status" value="1">
                                            <button type="submit" class="btn btn-sm btn-success">启用</button>
                                        </form>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>

                        <?php if (empty($suppliers)): ?>
                            <tr>
                                <td colspan="8" class="text-center">没有找到符合条件的供应商</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分页 -->
            <?php if ($total_pages > 1): ?>
                <div class="pagination">
                    <?php if ($page > 1): ?>
                        <a href="?page=1<?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link">首页</a>
                        <a href="?page=<?php echo $page - 1; ?><?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link">上一页</a>
                    <?php endif; ?>

                    <?php
                    $start_page = max(1, $page - 2);
                    $end_page = min($total_pages, $page + 2);

                    for ($i = $start_page; $i <= $end_page; $i++):
                    ?>
                        <a href="?page=<?php echo $i; ?><?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link <?php echo $i == $page ? 'current' : ''; ?>">
                            <?php echo $i; ?>
                        </a>
                    <?php endfor; ?>

                    <?php if ($page < $total_pages): ?>
                        <a href="?page=<?php echo $page + 1; ?><?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link">下一页</a>
                        <a href="?page=<?php echo $total_pages; ?><?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link">末页</a>
                    <?php endif; ?>
                </div>
                <div class="pagination-info">
                    共 <?php echo $total_records; ?> 条记录，当前第 <?php echo $page; ?>/<?php echo $total_pages; ?> 页
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 切换表单显示/隐藏
        function toggleForm(formId) {
            const form = document.getElementById(formId);
            if (form.style.display === 'none' || form.style.display === '') {
                form.style.display = 'block';
            } else {
                form.style.display = 'none';
            }
        }

        // 显示编辑供应商表单并填充数据
        function showEditForm(supplier) {
            // 填充表单字段
            document.getElementById('edit_supplier_id').value = supplier.id;
            document.getElementById('edit_name').value = supplier.name;
            document.getElementById('edit_contact_person').value = supplier.contact_person;
            document.getElementById('edit_phone').value = supplier.phone;
            document.getElementById('edit_address').value = supplier.address || '';
            document.getElementById('edit_status').checked = supplier.status == 1;

            // 显示表单
            document.getElementById('editSupplierForm').style.display = 'block';
        }
    </script>
</body>

</html>