<?php
// statistics/init_sales_data.php - 初始化销售统计数据
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('statistics.manage');

// 记录访问日志
record_log('执行销售统计数据初始化');

// 清空指定日期范围内的销售统计数据
function clear_sales_statistics($pdo, $start_date, $end_date)
{
    try {
        // 将日期转换为期望的格式
        $start_date_formatted = date('Ymd', strtotime($start_date));
        $end_date_formatted = date('Ymd', strtotime($end_date));

        // 删除日销售统计数据
        $stmt = $pdo->prepare("
            DELETE FROM data_statistics 
            WHERE statistic_type = 'sales' 
            AND period_type = 'day'
            AND period_value BETWEEN ? AND ?
        ");
        $stmt->execute([$start_date_formatted, $end_date_formatted]);

        // 删除商品销售统计数据
        $stmt = $pdo->prepare("
            DELETE FROM data_statistics 
            WHERE statistic_type = 'product' 
            AND period_type = 'day'
            AND period_value BETWEEN ? AND ?
        ");
        $stmt->execute([$start_date_formatted, $end_date_formatted]);

        return true;
    } catch (PDOException $e) {
        echo "清空统计数据失败: " . $e->getMessage() . "<br>";
        return false;
    }
}

// 生成日期销售统计数据
function generate_daily_sales_statistics($pdo, $start_date, $end_date)
{
    try {
        // 获取按日期统计的销售数据
        $stmt = $pdo->prepare("
            SELECT 
                DATE(o.create_time) AS order_date,
                COUNT(o.id) AS order_count,
                SUM(o.total_amount) AS total_amount
            FROM orders o
            WHERE o.status IN (1, 2, 3, 4) -- 已支付、配送中、已完成、部分退款的订单
            AND DATE(o.create_time) BETWEEN ? AND ?
            GROUP BY DATE(o.create_time)
        ");
        $stmt->execute([$start_date, $end_date]);
        $daily_sales = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // 插入日销售统计数据
        if (!empty($daily_sales)) {
            $insert_stmt = $pdo->prepare("
                INSERT INTO data_statistics 
                (statistic_type, reference_id, period_type, period_value, numeric_value1, numeric_value2, numeric_value3)
                VALUES ('sales', NULL, 'day', ?, ?, 0, ?)
                ON DUPLICATE KEY UPDATE numeric_value1 = VALUES(numeric_value1), numeric_value3 = VALUES(numeric_value3)
            ");

            foreach ($daily_sales as $sale) {
                $period_value = date('Ymd', strtotime($sale['order_date']));
                $insert_stmt->execute([
                    $period_value,
                    $sale['total_amount'],
                    $sale['order_count']
                ]);
            }
            echo "成功生成 " . count($daily_sales) . " 条日销售统计数据<br>";
        } else {
            echo "未找到符合条件的订单数据<br>";
        }

        return true;
    } catch (PDOException $e) {
        echo "生成日销售统计数据失败: " . $e->getMessage() . "<br>";
        return false;
    }
}

// 生成商品销售统计数据
function generate_product_sales_statistics($pdo, $start_date, $end_date)
{
    try {
        // 获取按商品统计的销售数据
        $stmt = $pdo->prepare("
            SELECT 
                DATE(o.create_time) AS order_date,
                oi.product_id,
                SUM(oi.quantity) AS total_quantity,
                SUM(oi.price * oi.quantity) AS total_amount
            FROM order_items oi
            JOIN orders o ON oi.order_id = o.id
            WHERE o.status IN (1, 2, 3, 4) -- 已支付、配送中、已完成、部分退款的订单
            AND DATE(o.create_time) BETWEEN ? AND ?
            GROUP BY DATE(o.create_time), oi.product_id
        ");
        $stmt->execute([$start_date, $end_date]);
        $product_sales = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // 插入商品销售统计数据
        if (!empty($product_sales)) {
            $insert_stmt = $pdo->prepare("
                INSERT INTO data_statistics 
                (statistic_type, reference_id, period_type, period_value, numeric_value1, numeric_value2, numeric_value3)
                VALUES ('product', ?, 'day', ?, ?, ?, 0)
                ON DUPLICATE KEY UPDATE 
                    numeric_value1 = VALUES(numeric_value1), 
                    numeric_value2 = VALUES(numeric_value2)
            ");

            foreach ($product_sales as $sale) {
                $period_value = date('Ymd', strtotime($sale['order_date']));
                $insert_stmt->execute([
                    $sale['product_id'],
                    $period_value,
                    $sale['total_amount'],
                    $sale['total_quantity']
                ]);
            }
            echo "成功生成 " . count($product_sales) . " 条商品销售统计数据<br>";
        } else {
            echo "未找到符合条件的商品销售数据<br>";
        }

        return true;
    } catch (PDOException $e) {
        echo "生成商品销售统计数据失败: " . $e->getMessage() . "<br>";
        return false;
    }
}

// 生成周/月统计数据
function generate_period_statistics($pdo, $start_date, $end_date)
{
    try {
        // 生成周销售统计
        $stmt = $pdo->prepare("
            INSERT INTO data_statistics 
            (statistic_type, reference_id, period_type, period_value, numeric_value1, numeric_value2, numeric_value3)
            SELECT 
                'sales', 
                NULL, 
                'week', 
                DATE_FORMAT(STR_TO_DATE(period_value, '%Y%m%d'), '%Y%u'), 
                SUM(numeric_value1), 
                0, 
                SUM(numeric_value3)
            FROM data_statistics
            WHERE statistic_type = 'sales'
            AND period_type = 'day'
            AND STR_TO_DATE(period_value, '%Y%m%d') BETWEEN ? AND ?
            GROUP BY DATE_FORMAT(STR_TO_DATE(period_value, '%Y%m%d'), '%Y%u')
            ON DUPLICATE KEY UPDATE 
                numeric_value1 = VALUES(numeric_value1), 
                numeric_value3 = VALUES(numeric_value3)
        ");
        $stmt->execute([$start_date, $end_date]);
        $week_rows = $stmt->rowCount();
        echo "成功生成 $week_rows 条周销售统计数据<br>";

        // 生成月销售统计
        $stmt = $pdo->prepare("
            INSERT INTO data_statistics 
            (statistic_type, reference_id, period_type, period_value, numeric_value1, numeric_value2, numeric_value3)
            SELECT 
                'sales', 
                NULL, 
                'month', 
                DATE_FORMAT(STR_TO_DATE(period_value, '%Y%m%d'), '%Y%m'), 
                SUM(numeric_value1), 
                0, 
                SUM(numeric_value3)
            FROM data_statistics
            WHERE statistic_type = 'sales'
            AND period_type = 'day'
            AND STR_TO_DATE(period_value, '%Y%m%d') BETWEEN ? AND ?
            GROUP BY DATE_FORMAT(STR_TO_DATE(period_value, '%Y%m%d'), '%Y%m')
            ON DUPLICATE KEY UPDATE 
                numeric_value1 = VALUES(numeric_value1), 
                numeric_value3 = VALUES(numeric_value3)
        ");
        $stmt->execute([$start_date, $end_date]);
        $month_rows = $stmt->rowCount();
        echo "成功生成 $month_rows 条月销售统计数据<br>";

        return true;
    } catch (PDOException $e) {
        echo "生成周/月统计数据失败: " . $e->getMessage() . "<br>";
        return false;
    }
}

// 生成示例数据
function generate_sample_data($pdo)
{
    try {
        // 获取一些基本数据
        $store_ids = [];
        $stmt = $pdo->query("SELECT id FROM stores LIMIT 5");
        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $store_ids[] = $row['id'];
        }

        $product_ids = [];
        $stmt = $pdo->query("SELECT id FROM products LIMIT 20");
        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $product_ids[] = $row['id'];
        }

        // 如果没有实际门店或商品数据，创建一些示例ID
        if (empty($store_ids)) {
            $store_ids = [1, 2, 3];
        }

        if (empty($product_ids)) {
            $product_ids = range(1, 10);
        }

        // 生成最近60天的示例销售数据
        $end_date = date('Y-m-d');
        $start_date = date('Y-m-d', strtotime('-60 days'));

        // 清空此时间范围的旧数据
        clear_sales_statistics($pdo, $start_date, $end_date);

        // 准备插入语句
        $insert_sales_stmt = $pdo->prepare("
            INSERT INTO data_statistics 
            (statistic_type, reference_id, period_type, period_value, numeric_value1, numeric_value2, numeric_value3)
            VALUES ('sales', NULL, 'day', ?, ?, 0, ?)
        ");

        $insert_product_stmt = $pdo->prepare("
            INSERT INTO data_statistics 
            (statistic_type, reference_id, period_type, period_value, numeric_value1, numeric_value2, numeric_value3)
            VALUES ('product', ?, 'day', ?, ?, ?, 0)
        ");

        $sample_count = 0;

        // 循环生成每天的数据
        for ($i = 0; $i < 60; $i++) {
            $date = date('Y-m-d', strtotime("-$i days"));
            $period_value = date('Ymd', strtotime($date));

            // 生成随机销售总额和订单数（周末销量更高）
            $is_weekend = (date('N', strtotime($date)) >= 6);
            $order_count = rand($is_weekend ? 10 : 5, $is_weekend ? 30 : 15);
            $total_amount = $order_count * rand(100, 300);

            // 插入日销售统计
            $insert_sales_stmt->execute([
                $period_value,
                $total_amount,
                $order_count
            ]);
            $sample_count++;

            // 为每天随机选择5-10个商品生成销售数据
            $selected_products = array_rand(array_flip($product_ids), rand(5, min(10, count($product_ids))));
            if (!is_array($selected_products)) {
                $selected_products = [$selected_products];
            }

            foreach ($selected_products as $product_id) {
                $quantity = rand(1, 10);
                $amount = $quantity * rand(50, 200);

                $insert_product_stmt->execute([
                    $product_id,
                    $period_value,
                    $amount,
                    $quantity
                ]);
                $sample_count++;
            }
        }

        echo "成功生成 $sample_count 条示例销售统计数据<br>";

        // 基于日数据生成周/月统计
        generate_period_statistics($pdo, $start_date, $end_date);

        return true;
    } catch (PDOException $e) {
        echo "生成示例数据失败: " . $e->getMessage() . "<br>";
        return false;
    }
}

// 处理表单提交
$message = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        $action = $_POST['action'] ?? '';

        if ($action === 'init_real_data') {
            // 初始化真实数据
            $start_date = $_POST['start_date'] ?? date('Y-m-d', strtotime('-90 days'));
            $end_date = $_POST['end_date'] ?? date('Y-m-d');

            // 开始事务
            $pdo->beginTransaction();

            // 清空指定日期范围内的统计数据
            if (clear_sales_statistics($pdo, $start_date, $end_date)) {
                // 生成新的统计数据
                if (
                    generate_daily_sales_statistics($pdo, $start_date, $end_date) &&
                    generate_product_sales_statistics($pdo, $start_date, $end_date) &&
                    generate_period_statistics($pdo, $start_date, $end_date)
                ) {

                    $pdo->commit();
                    $message = "成功初始化 $start_date 至 $end_date 的销售统计数据";
                } else {
                    $pdo->rollBack();
                    $message = "初始化销售统计数据失败";
                }
            } else {
                $pdo->rollBack();
                $message = "清空旧统计数据失败";
            }
        } else if ($action === 'generate_sample') {
            // 生成示例数据
            $pdo->beginTransaction();

            if (generate_sample_data($pdo)) {
                $pdo->commit();
                $message = "成功生成示例销售统计数据";
            } else {
                $pdo->rollBack();
                $message = "生成示例数据失败";
            }
        }
    } catch (Exception $e) {
        if ($pdo->inTransaction()) {
            $pdo->rollBack();
        }
        $message = "操作失败: " . $e->getMessage();
    }
}

// 获取统计表中已有数据的信息
try {
    $stats_info = [
        'sales_days' => 0,
        'total_records' => 0,
        'earliest_date' => '',
        'latest_date' => ''
    ];

    $stmt = $pdo->query("
        SELECT 
            COUNT(*) as total_records,
            COUNT(DISTINCT period_value) as unique_days,
            MIN(STR_TO_DATE(period_value, '%Y%m%d')) as earliest_date,
            MAX(STR_TO_DATE(period_value, '%Y%m%d')) as latest_date
        FROM data_statistics
        WHERE statistic_type = 'sales'
        AND period_type = 'day'
    ");
    if ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $stats_info['sales_days'] = $row['unique_days'];
        $stats_info['total_records'] = $row['total_records'];
        $stats_info['earliest_date'] = $row['earliest_date'];
        $stats_info['latest_date'] = $row['latest_date'];
    }
} catch (PDOException $e) {
    $message = "获取统计数据信息失败: " . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>销售统计数据初始化 - FloraEase花店管理系统</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>销售统计数据初始化</h2>
            <div class="breadcrumb">
                <a href="index.php">数据统计与分析</a> /
                <a href="sales.php">销售统计</a> / 数据初始化
            </div>
        </div>

        <div class="content">
            <?php if (!empty($message)): ?>
                <div class="alert alert-success">
                    <?php echo $message; ?>
                </div>
            <?php endif; ?>

            <div class="system-info">
                <h3>当前统计数据状态</h3>
                <table class="info-table">
                    <tr>
                        <td width="30%">销售统计天数：</td>
                        <td><?php echo $stats_info['sales_days']; ?> 天</td>
                    </tr>
                    <tr>
                        <td>统计记录总数：</td>
                        <td><?php echo $stats_info['total_records']; ?> 条</td>
                    </tr>
                    <tr>
                        <td>最早日期：</td>
                        <td><?php echo $stats_info['earliest_date'] ?: '无数据'; ?></td>
                    </tr>
                    <tr>
                        <td>最新日期：</td>
                        <td><?php echo $stats_info['latest_date'] ?: '无数据'; ?></td>
                    </tr>
                </table>
            </div>

            <div class="form-container">
                <h3>初始化真实销售统计数据</h3>
                <p>从订单数据中提取销售统计信息，生成日/周/月销售统计数据。</p>

                <form method="post" action="">
                    <input type="hidden" name="action" value="init_real_data">

                    <div class="form-group">
                        <label for="start_date">开始日期</label>
                        <input type="date" id="start_date" name="start_date" value="<?php echo date('Y-m-d', strtotime('-90 days')); ?>">
                    </div>

                    <div class="form-group">
                        <label for="end_date">结束日期</label>
                        <input type="date" id="end_date" name="end_date" value="<?php echo date('Y-m-d'); ?>">
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">初始化真实数据</button>
                    </div>
                </form>
            </div>

            <div class="form-container">
                <h3>生成示例销售统计数据</h3>
                <p>如果没有真实订单数据，可以生成示例数据用于测试和展示。</p>
                <p class="alert alert-danger" style="margin-top: 10px;">注意：此操作会生成最近60天的随机示例数据，仅用于测试展示，请勿在生产环境使用。</p>

                <form method="post" action="">
                    <input type="hidden" name="action" value="generate_sample">

                    <div class="form-actions">
                        <button type="submit" class="btn btn-danger" onclick="return confirm('确定要生成示例数据吗？这将覆盖最近60天的现有统计数据！')">生成示例数据</button>
                    </div>
                </form>
            </div>

            <div class="form-actions" style="margin-top: 20px;">
                <a href="sales.php" class="btn btn-secondary">返回销售统计</a>
            </div>
        </div>
    </div>
</body>

</html>