<?php
// store/stat.php - 门店营业统计
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('store.view');

// 处理操作请求
$action = isset($_GET['action']) ? $_GET['action'] : 'list';
$message = '';
$messageType = '';

// 处理统计数据添加
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $action === 'add') {
    // 检查添加权限
    check_permission_or_die('store.add');

    $store_id = $_POST['store_id'] ?? '';
    $date = $_POST['date'] ?? '';
    $period = $_POST['period'] ?? '';
    $sales_amount = $_POST['sales_amount'] ?? '';
    $order_count = $_POST['order_count'] ?? '';
    $peak_hours = $_POST['peak_hours'] ?? '';

    if (empty($store_id) || empty($date) || empty($period) || $sales_amount === '' || $order_count === '') {
        $message = '请填写所有必填字段';
        $messageType = 'danger';
    } else {
        try {
            // 检查是否已存在相同门店、日期和周期的记录
            $stmt = $pdo->prepare("SELECT id FROM store_statistics WHERE store_id = ? AND date = ? AND period = ?");
            $stmt->execute([$store_id, $date, $period]);
            $existRecord = $stmt->fetch();

            if ($existRecord) {
                $message = '该门店在指定日期和周期已有统计记录，请使用编辑功能更新';
                $messageType = 'danger';
            } else {
                $stmt = $pdo->prepare("INSERT INTO store_statistics (store_id, date, period, sales_amount, order_count, peak_hours) VALUES (?, ?, ?, ?, ?, ?)");
                $stmt->execute([$store_id, $date, $period, $sales_amount, $order_count, $peak_hours]);

                record_log("添加门店统计数据：门店ID $store_id，日期 $date，周期 $period");
                $message = '统计数据添加成功';
                $messageType = 'success';
                $action = 'list'; // 返回列表视图
            }
        } catch (PDOException $e) {
            $message = '统计数据添加失败: ' . $e->getMessage();
            $messageType = 'danger';
        }
    }
}

// 处理统计数据更新
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $action === 'edit') {
    // 检查编辑权限
    check_permission_or_die('store.edit');

    $id = $_POST['id'] ?? 0;
    $store_id = $_POST['store_id'] ?? '';
    $date = $_POST['date'] ?? '';
    $period = $_POST['period'] ?? '';
    $sales_amount = $_POST['sales_amount'] ?? '';
    $order_count = $_POST['order_count'] ?? '';
    $peak_hours = $_POST['peak_hours'] ?? '';

    if (empty($id) || empty($store_id) || empty($date) || empty($period) || $sales_amount === '' || $order_count === '') {
        $message = '请填写所有必填字段';
        $messageType = 'danger';
    } else {
        try {
            $stmt = $pdo->prepare("UPDATE store_statistics SET store_id = ?, date = ?, period = ?, sales_amount = ?, order_count = ?, peak_hours = ? WHERE id = ?");
            $stmt->execute([$store_id, $date, $period, $sales_amount, $order_count, $peak_hours, $id]);

            record_log("更新门店统计数据：ID $id，门店ID $store_id");
            $message = '统计数据更新成功';
            $messageType = 'success';
            $action = 'list'; // 返回列表视图
        } catch (PDOException $e) {
            $message = '统计数据更新失败: ' . $e->getMessage();
            $messageType = 'danger';
        }
    }
}

// 处理统计数据删除
if ($action === 'delete' && isset($_GET['id'])) {
    // 检查删除权限
    check_permission_or_die('store.delete');

    $id = $_GET['id'];

    try {
        $stmt = $pdo->prepare("DELETE FROM store_statistics WHERE id = ?");
        $stmt->execute([$id]);

        record_log("删除门店统计数据 (ID: $id)");
        $message = '统计数据删除成功';
        $messageType = 'success';
    } catch (PDOException $e) {
        $message = '统计数据删除失败: ' . $e->getMessage();
        $messageType = 'danger';
    }
    $action = 'list'; // 返回列表视图
}

// 获取单个统计数据（用于编辑和查看）
$statInfo = null;
if (($action === 'edit' || $action === 'view') && isset($_GET['id'])) {
    $id = $_GET['id'];
    try {
        $stmt = $pdo->prepare("SELECT st.*, s.name as store_name FROM store_statistics st LEFT JOIN stores s ON st.store_id = s.id WHERE st.id = ?");
        $stmt->execute([$id]);
        $statInfo = $stmt->fetch();

        if (!$statInfo) {
            $message = '统计数据不存在';
            $messageType = 'danger';
            $action = 'list'; // 返回列表视图
        }
    } catch (PDOException $e) {
        $message = '获取统计数据失败: ' . $e->getMessage();
        $messageType = 'danger';
        $action = 'list'; // 返回列表视图
    }
}

// 获取门店列表（用于选择门店）
$storesList = [];
try {
    $stmt = $pdo->query("SELECT id, name FROM stores ORDER BY id");
    $storesList = $stmt->fetchAll();
} catch (PDOException $e) {
    $message = '获取门店列表失败: ' . $e->getMessage();
    $messageType = 'danger';
}

// 获取统计数据列表（用于列表视图）
$stats = [];
$totalSalesAmount = 0;
$totalOrderCount = 0;
if ($action === 'list') {
    // 分页参数
    $page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
    $limit = 10;
    $offset = ($page - 1) * $limit;

    // 搜索条件
    $searchStore = isset($_GET['search_store']) ? $_GET['search_store'] : '';
    $searchPeriod = isset($_GET['search_period']) ? $_GET['search_period'] : '';
    $searchDateStart = isset($_GET['search_date_start']) ? $_GET['search_date_start'] : '';
    $searchDateEnd = isset($_GET['search_date_end']) ? $_GET['search_date_end'] : '';

    $where = [];
    $params = [];

    if (!empty($searchStore)) {
        $where[] = "st.store_id = ?";
        $params[] = $searchStore;
    }

    if (!empty($searchPeriod)) {
        $where[] = "st.period = ?";
        $params[] = $searchPeriod;
    }

    if (!empty($searchDateStart)) {
        $where[] = "st.date >= ?";
        $params[] = $searchDateStart;
    }

    if (!empty($searchDateEnd)) {
        $where[] = "st.date <= ?";
        $params[] = $searchDateEnd;
    }

    $whereClause = empty($where) ? "" : "WHERE " . implode(" AND ", $where);

    // 获取总销售额和总订单数
    $sumSql = "SELECT SUM(sales_amount) as total_sales, SUM(order_count) as total_orders FROM store_statistics st $whereClause";
    $stmt = $pdo->prepare($sumSql);
    $stmt->execute($params);
    $sumResult = $stmt->fetch();
    $totalSalesAmount = $sumResult['total_sales'] ?? 0;
    $totalOrderCount = $sumResult['total_orders'] ?? 0;

    // 获取总记录数
    $countSql = "SELECT COUNT(*) as total FROM store_statistics st $whereClause";
    $stmt = $pdo->prepare($countSql);
    $stmt->execute($params);
    $totalRecords = $stmt->fetch()['total'];
    $totalPages = ceil($totalRecords / $limit);

    // 获取分页数据
    $sql = "SELECT st.*, s.name as store_name FROM store_statistics st 
            LEFT JOIN stores s ON st.store_id = s.id 
            $whereClause 
            ORDER BY st.date DESC, st.store_id ASC LIMIT $offset, $limit";
    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $stats = $stmt->fetchAll();
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>营业统计 - FloraEase</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>营业统计</h2>
            <div class="breadcrumb">
                <a href="index.php">门店管理</a> / 营业统计
            </div>
        </div>

        <div class="content">
            <?php if (!empty($message)): ?>
                <div class="alert alert-<?php echo $messageType; ?>">
                    <?php echo $message; ?>
                </div>
            <?php endif; ?>

            <?php if ($action === 'list'): ?>
                <!-- 数据摘要 -->
                <div class="dashboard">
                    <div class="dashboard-card">
                        <h3>总销售额</h3>
                        <div class="number">￥<?php echo number_format($totalSalesAmount, 2); ?></div>
                        <div class="desc">当前筛选条件下的总销售额</div>
                    </div>
                    <div class="dashboard-card">
                        <h3>总订单数</h3>
                        <div class="number"><?php echo $totalOrderCount; ?></div>
                        <div class="desc">当前筛选条件下的总订单数</div>
                    </div>
                    <div class="dashboard-card">
                        <h3>平均客单价</h3>
                        <div class="number">￥<?php echo $totalOrderCount > 0 ? number_format($totalSalesAmount / $totalOrderCount, 2) : '0.00'; ?></div>
                        <div class="desc">总销售额 / 总订单数</div>
                    </div>
                </div>

                <!-- 操作栏 -->
                <div class="action-bar">
                    <?php if (has_permission('store.add')): ?>
                        <a href="?action=add" class="btn btn-primary">添加统计数据</a>
                    <?php endif; ?>
                </div>

                <!-- 搜索表单 -->
                <form method="get" action="stat.php" class="filter-form">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="search_store">门店</label>
                            <select id="search_store" name="search_store">
                                <option value="">全部门店</option>
                                <?php foreach ($storesList as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo $searchStore == $store['id'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="search_period">统计周期</label>
                            <select id="search_period" name="search_period">
                                <option value="">全部周期</option>
                                <option value="day" <?php echo $searchPeriod === 'day' ? 'selected' : ''; ?>>日</option>
                                <option value="week" <?php echo $searchPeriod === 'week' ? 'selected' : ''; ?>>周</option>
                                <option value="month" <?php echo $searchPeriod === 'month' ? 'selected' : ''; ?>>月</option>
                            </select>
                        </div>
                    </div>
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="search_date_start">开始日期</label>
                            <input type="date" id="search_date_start" name="search_date_start" value="<?php echo htmlspecialchars($searchDateStart ?? ''); ?>">
                        </div>
                        <div class="filter-item">
                            <label for="search_date_end">结束日期</label>
                            <input type="date" id="search_date_end" name="search_date_end" value="<?php echo htmlspecialchars($searchDateEnd ?? ''); ?>">
                        </div>
                    </div>
                    <div class="filter-buttons">
                        <button type="submit" class="btn btn-primary">搜索</button>
                        <a href="?action=list" class="btn btn-secondary">重置</a>
                    </div>
                </form>

                <!-- 统计数据列表 -->
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>门店</th>
                                <th>日期</th>
                                <th>周期</th>
                                <th>销售额</th>
                                <th>订单数</th>
                                <th>高峰小时数</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($stats as $stat): ?>
                                <tr>
                                    <td><?php echo $stat['id']; ?></td>
                                    <td><?php echo htmlspecialchars($stat['store_name']); ?></td>
                                    <td><?php echo $stat['date']; ?></td>
                                    <td><?php if ($stat['period'] == 'day') {
                                            echo '日';
                                        } elseif ($stat['period'] == 'week') {
                                            echo '周';
                                        } elseif ($stat['period'] == 'month') {
                                            echo '月';
                                        } ?></td>
                                    <td>￥<?php echo number_format($stat['sales_amount'], 2); ?></td>
                                    <td><?php echo $stat['order_count']; ?></td>
                                    <td><?php echo $stat['peak_hours']; ?></td>
                                    <td>
                                        <a href="?action=view&id=<?php echo $stat['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                        <?php if (has_permission('store.edit')): ?>
                                            <a href="?action=edit&id=<?php echo $stat['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                        <?php endif; ?>
                                        <?php if (has_permission('store.delete')): ?>
                                            <a href="?action=delete&id=<?php echo $stat['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此统计数据吗？')">删除</a>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                            <?php if (empty($stats)): ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无统计数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 分页 -->
                <?php if ($totalPages > 1): ?>
                    <div class="pagination">
                        <?php if ($page > 1): ?>
                            <a href="?action=list&page=1<?php echo !empty($searchStore) ? '&search_store=' . $searchStore : ''; ?><?php echo !empty($searchPeriod) ? '&search_period=' . $searchPeriod : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link">首页</a>
                            <a href="?action=list&page=<?php echo $page - 1; ?><?php echo !empty($searchStore) ? '&search_store=' . $searchStore : ''; ?><?php echo !empty($searchPeriod) ? '&search_period=' . $searchPeriod : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link">上一页</a>
                        <?php endif; ?>

                        <?php
                        $startPage = max(1, $page - 2);
                        $endPage = min($totalPages, $page + 2);

                        for ($i = $startPage; $i <= $endPage; $i++):
                        ?>
                            <a href="?action=list&page=<?php echo $i; ?><?php echo !empty($searchStore) ? '&search_store=' . $searchStore : ''; ?><?php echo !empty($searchPeriod) ? '&search_period=' . $searchPeriod : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link <?php echo $i == $page ? 'current' : ''; ?>"><?php echo $i; ?></a>
                        <?php endfor; ?>

                        <?php if ($page < $totalPages): ?>
                            <a href="?action=list&page=<?php echo $page + 1; ?><?php echo !empty($searchStore) ? '&search_store=' . $searchStore : ''; ?><?php echo !empty($searchPeriod) ? '&search_period=' . $searchPeriod : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link">下一页</a>
                            <a href="?action=list&page=<?php echo $totalPages; ?><?php echo !empty($searchStore) ? '&search_store=' . $searchStore : ''; ?><?php echo !empty($searchPeriod) ? '&search_period=' . $searchPeriod : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link">末页</a>
                        <?php endif; ?>
                    </div>
                    <div class="pagination-info">
                        共 <?php echo $totalRecords; ?> 条记录，当前 <?php echo $page; ?>/<?php echo $totalPages; ?> 页
                    </div>
                <?php endif; ?>

            <?php elseif ($action === 'add' || $action === 'edit'): ?>
                <!-- 添加/编辑统计数据表单 -->
                <form method="post" action="?action=<?php echo $action; ?>" class="form-container">
                    <h3><?php echo $action === 'add' ? '添加统计数据' : '编辑统计数据'; ?></h3>

                    <?php if ($action === 'edit'): ?>
                        <input type="hidden" name="id" value="<?php echo $statInfo['id']; ?>">
                    <?php endif; ?>

                    <div class="form-group">
                        <label for="store_id">所属门店 *</label>
                        <select id="store_id" name="store_id" required>
                            <option value="">请选择门店</option>
                            <?php foreach ($storesList as $store): ?>
                                <option value="<?php echo $store['id']; ?>" <?php echo ($action === 'edit' && $statInfo['store_id'] == $store['id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($store['name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="date">日期 *</label>
                        <input type="date" id="date" name="date" value="<?php echo $action === 'edit' ? $statInfo['date'] : date('Y-m-d'); ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="period">周期 *</label>
                        <select id="period" name="period" required>
                            <option value="">请选择周期</option>
                            <option value="day" <?php echo $action === 'edit' && $statInfo['period'] == 'day' ? 'selected' : ''; ?>>日</option>
                            <option value="week" <?php echo $action === 'edit' && $statInfo['period'] == 'week' ? 'selected' : ''; ?>>周</option>
                            <option value="month" <?php echo $action === 'edit' && $statInfo['period'] == 'month' ? 'selected' : ''; ?>>月</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="sales_amount">销售额 *</label>
                        <input type="text" id="sales_amount" name="sales_amount" value="<?php echo $action === 'edit' ? $statInfo['sales_amount'] : ''; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="order_count">订单数 *</label>
                        <input type="text" id="order_count" name="order_count" value="<?php echo $action === 'edit' ? $statInfo['order_count'] : ''; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="peak_hours">高峰小时数</label>
                        <input type="text" id="peak_hours" name="peak_hours" value="<?php echo $action === 'edit' ? $statInfo['peak_hours'] : ''; ?>">
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary"><?php echo $action === 'add' ? '添加' : '保存'; ?></button>
                        <a href="?action=list" class="btn btn-secondary">取消</a>
                    </div>
                </form>

            <?php elseif ($action === 'view'): ?>
                <!-- 统计数据详情 -->
                <div class="form-container">
                    <h3>统计数据详情</h3>

                    <table class="info-table">
                        <tr>
                            <td width="20%">统计ID：</td>
                            <td><?php echo $statInfo['id']; ?></td>
                        </tr>
                        <tr>
                            <td>所属门店：</td>
                            <td><?php echo htmlspecialchars($statInfo['store_name']); ?></td>
                        </tr>
                        <tr>
                            <td>日期：</td>
                            <td><?php echo $statInfo['date']; ?></td>
                        </tr>
                        <tr>
                            <td>周期：</td>
                            <td><?php echo htmlspecialchars($statInfo['period']); ?></td>
                        </tr>
                        <tr>
                            <td>销售额：</td>
                            <td>￥<?php echo number_format($statInfo['sales_amount'], 2); ?></td>
                        </tr>
                        <tr>
                            <td>订单数：</td>
                            <td><?php echo $statInfo['order_count']; ?></td>
                        </tr>
                        <tr>
                            <td>高峰小时数：</td>
                            <td><?php echo $statInfo['peak_hours']; ?></td>
                        </tr>
                    </table>

                    <div class="form-actions">
                        <?php if (has_permission('store.edit')): ?>
                            <a href="?action=edit&id=<?php echo $statInfo['id']; ?>" class="btn btn-primary">编辑</a>
                        <?php endif; ?>
                        <a href="?action=list" class="btn btn-secondary">返回</a>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>