<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('system_user');

// 记录访问日志
record_log('访问用户管理页面');

// 添加/编辑用户处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加用户
    if ($_POST['action'] == 'add') {
        $username = isset($_POST['username']) ? trim($_POST['username']) : '';
        $password = isset($_POST['password']) ? trim($_POST['password']) : '';
        $role_id = isset($_POST['role_id']) ? intval($_POST['role_id']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($username) || empty($password) || $role_id <= 0) {
            $error = '请填写完整用户信息！';
        } else {
            try {
                // 检查用户名是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sys_users WHERE username = ?");
                $stmt->execute([$username]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '用户名已存在！';
                } else {
                    // 添加用户
                    $stmt = $pdo->prepare("INSERT INTO sys_users (username, password, role_id, status) VALUES (?, ?, ?, ?)");
                    $result = $stmt->execute([$username, $password, $role_id, $status]);

                    if ($result) {
                        record_log("添加用户：{$username}");
                        $success = '用户添加成功！';
                    } else {
                        $error = '用户添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑用户
    elseif ($_POST['action'] == 'edit') {
        $user_id = isset($_POST['user_id']) ? intval($_POST['user_id']) : 0;
        $username = isset($_POST['username']) ? trim($_POST['username']) : '';
        $password = isset($_POST['password']) ? trim($_POST['password']) : '';
        $role_id = isset($_POST['role_id']) ? intval($_POST['role_id']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($user_id <= 0 || empty($username) || $role_id <= 0) {
            $error = '请填写完整用户信息！';
        } else {
            try {
                // 检查用户名是否已被其他用户使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sys_users WHERE username = ? AND id != ?");
                $stmt->execute([$username, $user_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '用户名已被其他用户使用！';
                } else {
                    // 更新用户信息
                    if (empty($password)) {
                        // 不更新密码
                        $stmt = $pdo->prepare("UPDATE sys_users SET username = ?, role_id = ?, status = ? WHERE id = ?");
                        $result = $stmt->execute([$username, $role_id, $status, $user_id]);
                    } else {
                        // 更新密码
                        $stmt = $pdo->prepare("UPDATE sys_users SET username = ?, password = ?, role_id = ?, status = ? WHERE id = ?");
                        $result = $stmt->execute([$username, $password, $role_id, $status, $user_id]);
                    }

                    if ($result) {
                        record_log("编辑用户：{$username}");
                        $success = '用户信息更新成功！';
                    } else {
                        $error = '用户信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除用户
    elseif ($_POST['action'] == 'delete') {
        $user_id = isset($_POST['user_id']) ? intval($_POST['user_id']) : 0;

        if ($user_id <= 0) {
            $error = '无效的用户ID！';
        } else {
            try {
                // 获取用户名，用于日志记录
                $stmt = $pdo->prepare("SELECT username FROM sys_users WHERE id = ?");
                $stmt->execute([$user_id]);
                $user = $stmt->fetch();

                if (!$user) {
                    $error = '用户不存在！';
                } else {
                    // 删除用户
                    $stmt = $pdo->prepare("DELETE FROM sys_users WHERE id = ?");
                    $result = $stmt->execute([$user_id]);

                    if ($result) {
                        record_log("删除用户：{$user['username']}");
                        $success = '用户删除成功！';
                    } else {
                        $error = '用户删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有角色
try {
    $stmt = $pdo->query("SELECT id, role_name FROM sys_roles ORDER BY id");
    $roles = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取角色列表失败：' . $e->getMessage();
    $roles = [];
}

// 获取所有用户
try {
    $stmt = $pdo->query("
        SELECT u.*, r.role_name 
        FROM sys_users u 
        LEFT JOIN sys_roles r ON u.role_id = r.id 
        ORDER BY u.id
    ");
    $users = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取用户列表失败：' . $e->getMessage();
    $users = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>用户管理</h2>
            <div class="breadcrumb">
                <a href="index.php">系统设置</a> &gt; 用户管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <button class="btn btn-primary" onclick="showAddForm()">添加用户</button>
            </div>

            <!-- 添加用户表单 -->
            <div id="addUserForm" class="form-container" style="display: none;">
                <h3>添加用户</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="add">

                    <div class="form-group">
                        <label for="username">用户名：</label>
                        <input type="text" id="username" name="username" required>
                    </div>

                    <div class="form-group">
                        <label for="password">密码：</label>
                        <input type="password" id="password" name="password" required>
                    </div>

                    <div class="form-group">
                        <label for="role_id">角色：</label>
                        <select id="role_id" name="role_id" required>
                            <option value="">选择角色</option>
                            <?php foreach ($roles as $role): ?>
                                <option value="<?php echo $role['id']; ?>"><?php echo htmlspecialchars($role['role_name']); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="status">状态：</label>
                        <select id="status" name="status">
                            <option value="1">启用</option>
                            <option value="0">禁用</option>
                        </select>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="hideAddForm()">取消</button>
                    </div>
                </form>
            </div>

            <!-- 编辑用户表单 -->
            <div id="editUserForm" class="form-container" style="display: none;">
                <h3>编辑用户</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="edit">
                    <input type="hidden" name="user_id" id="edit_user_id">

                    <div class="form-group">
                        <label for="edit_username">用户名：</label>
                        <input type="text" id="edit_username" name="username" required>
                    </div>

                    <div class="form-group">
                        <label for="edit_password">密码：</label>
                        <input type="password" id="edit_password" name="password" placeholder="留空表示不修改密码">
                    </div>

                    <div class="form-group">
                        <label for="edit_role_id">角色：</label>
                        <select id="edit_role_id" name="role_id" required>
                            <option value="">选择角色</option>
                            <?php foreach ($roles as $role): ?>
                                <option value="<?php echo $role['id']; ?>"><?php echo htmlspecialchars($role['role_name']); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="edit_status">状态：</label>
                        <select id="edit_status" name="status">
                            <option value="1">启用</option>
                            <option value="0">禁用</option>
                        </select>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="hideEditForm()">取消</button>
                    </div>
                </form>
            </div>

            <!-- 用户列表 -->
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>用户名</th>
                            <th>角色</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($users)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无用户数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($users as $user): ?>
                                <tr>
                                    <td><?php echo $user['id']; ?></td>
                                    <td><?php echo htmlspecialchars($user['username']); ?></td>
                                    <td><?php echo htmlspecialchars($user['role_name']); ?></td>
                                    <td>
                                        <?php if ($user['status'] == 1): ?>
                                            <span class="status-active">启用</span>
                                        <?php else: ?>
                                            <span class="status-inactive">禁用</span>
                                        <?php endif; ?>
                                    </td>
                                    <td><?php echo $user['create_time']; ?></td>
                                    <td>
                                        <button class="btn btn-sm btn-primary" onclick="editUser(<?php echo $user['id']; ?>, '<?php echo htmlspecialchars($user['username']); ?>', <?php echo $user['role_id']; ?>, <?php echo $user['status']; ?>)">编辑</button>
                                        <?php if ($user['id'] != 1): // 防止删除超级管理员 
                                        ?>
                                            <button class="btn btn-sm btn-danger" onclick="deleteUser(<?php echo $user['id']; ?>, '<?php echo htmlspecialchars($user['username']); ?>')">删除</button>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 删除用户表单 -->
            <form id="deleteUserForm" method="post" action="" style="display: none;">
                <input type="hidden" name="action" value="delete">
                <input type="hidden" name="user_id" id="delete_user_id">
            </form>
        </div>
    </div>

    <script>
        // 显示添加用户表单
        function showAddForm() {
            document.getElementById('addUserForm').style.display = 'block';
        }

        // 隐藏添加用户表单
        function hideAddForm() {
            document.getElementById('addUserForm').style.display = 'none';
        }

        // 显示编辑用户表单
        function editUser(id, username, role_id, status) {
            document.getElementById('edit_user_id').value = id;
            document.getElementById('edit_username').value = username;
            document.getElementById('edit_password').value = '';
            document.getElementById('edit_role_id').value = role_id;
            document.getElementById('edit_status').value = status;
            document.getElementById('editUserForm').style.display = 'block';
        }

        // 隐藏编辑用户表单
        function hideEditForm() {
            document.getElementById('editUserForm').style.display = 'none';
        }

        // 删除用户确认
        function deleteUser(id, username) {
            if (confirm('确定要删除用户 "' + username + '" 吗？')) {
                document.getElementById('delete_user_id').value = id;
                document.getElementById('deleteUserForm').submit();
            }
        }
    </script>
</body>

</html>